% Auto-generated chapter 3 for bukhari
% Hadiths in this chapter: 76

\hadithdefcmd{bukhari}{59}{حَدَّثَنَا مُحَمَّدُ بْنُ سِنَانٍ، قَالَ حَدَّثَنَا فُلَيْحٌ، ح وَحَدَّثَنِي إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ فُلَيْحٍ، قَالَ حَدَّثَنِي أَبِي قَالَ، حَدَّثَنِي هِلاَلُ بْنُ عَلِيٍّ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ بَيْنَمَا النَّبِيُّ صلى الله عليه وسلم فِي مَجْلِسٍ يُحَدِّثُ الْقَوْمَ جَاءَهُ أَعْرَابِيٌّ فَقَالَ مَتَى السَّاعَةُ فَمَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم يُحَدِّثُ، فَقَالَ بَعْضُ الْقَوْمِ سَمِعَ مَا قَالَ، فَكَرِهَ مَا قَالَ، وَقَالَ بَعْضُهُمْ بَلْ لَمْ يَسْمَعْ، حَتَّى إِذَا قَضَى حَدِيثَهُ قَالَ ‏"‏ أَيْنَ ـ أُرَاهُ ـ السَّائِلُ عَنِ السَّاعَةِ ‏"‏‏.‏ قَالَ هَا أَنَا يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ فَإِذَا ضُيِّعَتِ الأَمَانَةُ فَانْتَظِرِ السَّاعَةَ ‏"‏‏.‏ قَالَ كَيْفَ إِضَاعَتُهَا قَالَ ‏"‏ إِذَا وُسِّدَ الأَمْرُ إِلَى غَيْرِ أَهْلِهِ فَانْتَظِرِ السَّاعَةَ ‏"‏‏.‏\hadithno{59}\hadithtrans{Narrated Abu Huraira:While the Prophet (ﷺ) was saying something in a gathering, a Bedouin came and asked him, "When would the Hour (Doomsday) take place?" Allah's Messenger (ﷺ) continued his talk, so some people said that Allah's Messenger (ﷺ) had heard the question, but did not like what that Bedouin had asked. Some of them said that Allah's Messenger (ﷺ) had not heard it. When the Prophet (ﷺ) finished his speech, he said, "Where is the questioner, who inquired about the Hour (Doomsday)?" The Bedouin said, "I am here, O Allah's Apostle ." Then the Prophet (ﷺ) said, "When honesty is lost, then wait for the Hour (Doomsday)." The Bedouin said, "How will that be lost?" The Prophet (ﷺ) said, "When the power or authority comes in the hands of unfit persons, then wait for the Hour (Doomsday)}}
\hadithdefcmd{bukhari}{60}{حَدَّثَنَا أَبُو النُّعْمَانِ، عَارِمُ بْنُ الْفَضْلِ قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي بِشْرٍ، عَنْ يُوسُفَ بْنِ مَاهَكَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ تَخَلَّفَ عَنَّا النَّبِيُّ صلى الله عليه وسلم فِي سَفْرَةٍ سَافَرْنَاهَا، فَأَدْرَكَنَا وَقَدْ أَرْهَقَتْنَا الصَّلاَةُ وَنَحْنُ نَتَوَضَّأُ، فَجَعَلْنَا نَمْسَحُ عَلَى أَرْجُلِنَا، فَنَادَى بِأَعْلَى صَوْتِهِ ‏ "‏ وَيْلٌ لِلأَعْقَابِ مِنَ النَّارِ ‏"‏‏.‏ مَرَّتَيْنِ أَوْ ثَلاَثًا‏.‏\hadithno{60}\hadithtrans{Narrated `Abdullah bin `Amr:Once the Prophet (ﷺ) remained behind us in a journey. He joined us while we were performing ablution for the prayer which was over-due. We were just passing wet hands over our feet (and not washing them properly) so the Prophet (ﷺ) addressed us in a loud voice and said twice or thrice: "Save your heels from the fire}}
\hadithdefcmd{bukhari}{61}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ مِنَ الشَّجَرِ شَجَرَةً لاَ يَسْقُطُ وَرَقُهَا، وَإِنَّهَا مَثَلُ الْمُسْلِمِ، فَحَدِّثُونِي مَا هِيَ ‏"‏‏.‏ فَوَقَعَ النَّاسُ فِي شَجَرِ الْبَوَادِي‏.‏ قَالَ عَبْدُ اللَّهِ وَوَقَعَ فِي نَفْسِي أَنَّهَا النَّخْلَةُ، فَاسْتَحْيَيْتُ ثُمَّ قَالُوا حَدِّثْنَا مَا هِيَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ هِيَ النَّخْلَةُ ‏"‏‏.‏\hadithno{61}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) said, "Amongst the trees, there is a tree, the leaves of which do not fall and is like a Muslim. Tell me the name of that tree." Everybody started thinking about the trees of the desert areas. And I thought of the date-palm tree but felt shy to answer the others then asked, "What is that tree, O Allah's Messenger (ﷺ) ?" He replied, "It is the date-palm tree}}
\hadithdefcmd{bukhari}{62}{حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، حَدَّثَنَا سُلَيْمَانُ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دِينَارٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ مِنَ الشَّجَرِ شَجَرَةً لاَ يَسْقُطُ وَرَقُهَا، وَإِنَّهَا مَثَلُ الْمُسْلِمِ، حَدِّثُونِي مَا هِيَ ‏"‏‏.‏ قَالَ فَوَقَعَ النَّاسُ فِي شَجَرِ الْبَوَادِي‏.‏ قَالَ عَبْدُ اللَّهِ فَوَقَعَ فِي نَفْسِي أَنَّهَا النَّخْلَةُ، ثُمَّ قَالُوا حَدِّثْنَا مَا هِيَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ هِيَ النَّخْلَةُ ‏"‏‏.‏\hadithno{62}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) said, "Amongst the trees, there is a tree, the leaves of which do not fall and is like a Muslim. Tell me the name of that tree." Everybody started thinking about the trees of the desert areas. And I thought of the date-palm tree. The others then asked, "Please inform us what is that tree, O Allah's Messenger (ﷺ)?" He replied, "It is the date-palm tree}}
\hadithdefcmd{bukhari}{63}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ سَعِيدٍ ـ هُوَ الْمَقْبُرِيُّ ـ عَنْ شَرِيكِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي نَمِرٍ، أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ، يَقُولُ بَيْنَمَا نَحْنُ جُلُوسٌ مَعَ النَّبِيِّ صلى الله عليه وسلم فِي الْمَسْجِدِ، دَخَلَ رَجُلٌ عَلَى جَمَلٍ فَأَنَاخَهُ فِي الْمَسْجِدِ، ثُمَّ عَقَلَهُ، ثُمَّ قَالَ لَهُمْ أَيُّكُمْ مُحَمَّدٌ وَالنَّبِيُّ صلى الله عليه وسلم مُتَّكِئٌ بَيْنَ ظَهْرَانَيْهِمْ‏.‏ فَقُلْنَا هَذَا الرَّجُلُ الأَبْيَضُ الْمُتَّكِئُ‏.‏ فَقَالَ لَهُ الرَّجُلُ ابْنَ عَبْدِ الْمُطَّلِبِ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ قَدْ أَجَبْتُكَ ‏"‏‏.‏ فَقَالَ الرَّجُلُ لِلنَّبِيِّ صلى الله عليه وسلم إِنِّي سَائِلُكَ فَمُشَدِّدٌ عَلَيْكَ فِي الْمَسْأَلَةِ فَلاَ تَجِدْ عَلَىَّ فِي نَفْسِكَ‏.‏ فَقَالَ ‏"‏ سَلْ عَمَّا بَدَا لَكَ ‏"‏‏.‏ فَقَالَ أَسْأَلُكَ بِرَبِّكَ وَرَبِّ مَنْ قَبْلَكَ، آللَّهُ أَرْسَلَكَ إِلَى النَّاسِ كُلِّهِمْ فَقَالَ ‏"‏ اللَّهُمَّ نَعَمْ ‏"‏‏.‏ قَالَ أَنْشُدُكَ بِاللَّهِ، آللَّهُ أَمَرَكَ أَنْ نُصَلِّيَ الصَّلَوَاتِ الْخَمْسَ فِي الْيَوْمِ وَاللَّيْلَةِ قَالَ ‏"‏ اللَّهُمَّ نَعَمْ ‏"‏‏.‏ قَالَ أَنْشُدُكَ بِاللَّهِ، آللَّهُ أَمَرَكَ أَنْ نَصُومَ هَذَا الشَّهْرَ مِنَ السَّنَةِ قَالَ ‏"‏ اللَّهُمَّ نَعَمْ ‏"‏‏.‏ قَالَ أَنْشُدُكَ بِاللَّهِ، آللَّهُ أَمَرَكَ أَنْ تَأْخُذَ هَذِهِ الصَّدَقَةَ مِنْ أَغْنِيَائِنَا فَتَقْسِمَهَا عَلَى فُقَرَائِنَا فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ اللَّهُمَّ نَعَمْ ‏"‏‏.‏ فَقَالَ الرَّجُلُ آمَنْتُ بِمَا جِئْتَ بِهِ، وَأَنَا رَسُولُ مَنْ وَرَائِي مِنْ قَوْمِي، وَأَنَا ضِمَامُ بْنُ ثَعْلَبَةَ أَخُو بَنِي سَعْدِ بْنِ بَكْرٍ‏.‏ رَوَاهُ مُوسَى وَعَلِيُّ بْنُ عَبْدِ الْحَمِيدِ عَنْ سُلَيْمَانَ عَنْ ثَابِتٍ عَنْ أَنَسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا‏.‏\hadithno{63}\hadithtrans{Narrated Anas bin Malik:While we were sitting with the Prophet (ﷺ) in the mosque, a man came riding on a camel. He made his camel kneel down in the mosque, tied its foreleg and then said: "Who amongst you is Muhammad?" At that time the Prophet (ﷺ) was sitting amongst us (his companions) leaning on his arm. We replied, "This white man reclining on his arm." The man then addressed him, "O Son of `Abdul Muttalib." The Prophet (ﷺ) said, "I am here to answer your questions." The man said to the Prophet, "I want to ask you something and will be hard in questioning. So do not get angry." The Prophet (ﷺ) said, "Ask whatever you want." The man said, "I ask you by your Lord, and the Lord of those who were before you, has Allah sent you as an Apostle to all the mankind?" The Prophet (ﷺ) replied, "By Allah, yes." The man further said, "I ask you by Allah. Has Allah ordered you to offer five prayers in a day and night (24 hours)? He replied, "By Allah, Yes." The man further said, "I ask you by Allah! Has Allah ordered you to observe fasts during this month of the year (i.e. Ramadan)?" He replied, "By Allah, Yes." The man further said, "I ask you by Allah. Has Allah ordered you to take Zakat (obligatory charity) from our rich people and distribute it amongst our poor people?" The Prophet (ﷺ) replied, "By Allah, yes." Thereupon that man said, "I have believed in all that with which you have been sent, and I have been sent by my people as a messenger, and I am Dimam bin Tha`laba from the brothers of Bani Sa`d bin Bakr}}
\hadithdefcmd{bukhari}{64}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ، أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَ بِكِتَابِهِ رَجُلاً، وَأَمَرَهُ أَنْ يَدْفَعَهُ إِلَى عَظِيمِ الْبَحْرَيْنِ، فَدَفَعَهُ عَظِيمُ الْبَحْرَيْنِ إِلَى كِسْرَى، فَلَمَّا قَرَأَهُ مَزَّقَهُ‏.‏ فَحَسِبْتُ أَنَّ ابْنَ الْمُسَيَّبِ قَالَ فَدَعَا عَلَيْهِمْ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُمَزَّقُوا كُلَّ مُمَزَّقٍ‏.‏\hadithno{64}\hadithtrans{Narrated `Abdullah bin `Abbas:Once Allah's Messenger (ﷺ) gave a letter to a person and ordered him to go and deliver it to the Governor of Bahrain. (He did so) and the Governor of Bahrain sent it to Chousroes, who read that letter and then tore it to pieces. (The sub-narrator (Ibn Shihab) thinks that Ibn Al-Musaiyab said that Allah's Messenger (ﷺ) invoked Allah against them (saying), "May Allah tear them into pieces, and disperse them all totally}}
\hadithdefcmd{bukhari}{65}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ أَبُو الْحَسَنِ، أَخْبَرَنَا عَبْدُ اللَّهِ، قَالَ أَخْبَرَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَتَبَ النَّبِيُّ صلى الله عليه وسلم كِتَابًا ـ أَوْ أَرَادَ أَنْ يَكْتُبَ ـ فَقِيلَ لَهُ إِنَّهُمْ لاَ يَقْرَءُونَ كِتَابًا إِلاَّ مَخْتُومًا‏.‏ فَاتَّخَذَ خَاتَمًا مِنْ فِضَّةٍ نَقْشُهُ مُحَمَّدٌ رَسُولُ اللَّهِ‏.‏ كَأَنِّي أَنْظُرُ إِلَى بَيَاضِهِ فِي يَدِهِ‏.‏ فَقُلْتُ لِقَتَادَةَ مَنْ قَالَ نَقْشُهُ مُحَمَّدٌ رَسُولُ اللَّهِ قَالَ أَنَسٌ‏.‏\hadithno{65}\hadithtrans{Narrated Anas bin Malik:Once the Prophet (ﷺ) wrote a letter or had an idea of writing a letter. The Prophet (ﷺ) was told that they (rulers) would not read letters unless they were sealed. So the Prophet (ﷺ) got a silver ring made with "Muhammad Allah's Messenger (ﷺ)" engraved on it. As if I were just observing its white glitter in the hand of the Prophet}}
\hadithdefcmd{bukhari}{66}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، أَنَّ أَبَا مُرَّةَ، مَوْلَى عَقِيلِ بْنِ أَبِي طَالِبٍ أَخْبَرَهُ عَنْ أَبِي وَاقِدٍ اللَّيْثِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَيْنَمَا هُوَ جَالِسٌ فِي الْمَسْجِدِ وَالنَّاسُ مَعَهُ، إِذْ أَقْبَلَ ثَلاَثَةُ نَفَرٍ، فَأَقْبَلَ اثْنَانِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَذَهَبَ وَاحِدٌ، قَالَ فَوَقَفَا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَمَّا أَحَدُهُمَا فَرَأَى فُرْجَةً فِي الْحَلْقَةِ فَجَلَسَ فِيهَا، وَأَمَّا الآخَرُ فَجَلَسَ خَلْفَهُمْ، وَأَمَّا الثَّالِثُ فَأَدْبَرَ ذَاهِبًا، فَلَمَّا فَرَغَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَلاَ أُخْبِرُكُمْ عَنِ النَّفَرِ الثَّلاَثَةِ أَمَّا أَحَدُهُمْ فَأَوَى إِلَى اللَّهِ، فَآوَاهُ اللَّهُ، وَأَمَّا الآخَرُ فَاسْتَحْيَا، فَاسْتَحْيَا اللَّهُ مِنْهُ، وَأَمَّا الآخَرُ فَأَعْرَضَ، فَأَعْرَضَ اللَّهُ عَنْهُ ‏"‏‏.‏\hadithno{66}\hadithtrans{Narrated Abu Waqid Al-Laithi:While Allah's Messenger (ﷺ) was sitting in the mosque with some people, three men came. Two of them came in front of Allah's Messenger (ﷺ) and the third one went away. The two persons kept on standing before Allah's Messenger (ﷺ) for a while and then one of them found a place in the circle and sat there while the other sat behind the gathering, and the third one went away. When Allah's Messenger (ﷺ) finished his preaching, he said, "Shall I tell you about these three persons? One of them betook himself to Allah, so Allah took him into His grace and mercy and accommodated him, the second felt shy from Allah, so Allah sheltered Him in His mercy (and did not punish him), while the third turned his face from Allah and went away, so Allah turned His face from him likewise}}
\hadithdefcmd{bukhari}{67}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا بِشْرٌ، قَالَ حَدَّثَنَا ابْنُ عَوْنٍ، عَنِ ابْنِ سِيرِينَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرَةَ، عَنْ أَبِيهِ، ذَكَرَ النَّبِيَّ صلى الله عليه وسلم قَعَدَ عَلَى بَعِيرِهِ، وَأَمْسَكَ إِنْسَانٌ بِخِطَامِهِ ـ أَوْ بِزِمَامِهِ ـ قَالَ ‏"‏ أَىُّ يَوْمٍ هَذَا ‏"‏‏.‏ فَسَكَتْنَا حَتَّى ظَنَنَّا أَنَّهُ سَيُسَمِّيهِ سِوَى اسْمِهِ‏.‏ قَالَ ‏"‏ أَلَيْسَ يَوْمَ النَّحْرِ ‏"‏‏.‏ قُلْنَا بَلَى‏.‏ قَالَ ‏"‏ فَأَىُّ شَهْرٍ هَذَا ‏"‏‏.‏ فَسَكَتْنَا حَتَّى ظَنَنَّا أَنَّهُ سَيُسَمِّيهِ بِغَيْرِ اسْمِهِ‏.‏ فَقَالَ ‏"‏ أَلَيْسَ بِذِي الْحِجَّةِ ‏"‏‏.‏ قُلْنَا بَلَى‏.‏ قَالَ ‏"‏ فَإِنَّ دِمَاءَكُمْ وَأَمْوَالَكُمْ وَأَعْرَاضَكُمْ بَيْنَكُمْ حَرَامٌ كَحُرْمَةِ يَوْمِكُمْ هَذَا، فِي شَهْرِكُمْ هَذَا، فِي بَلَدِكُمْ هَذَا‏.‏ لِيُبَلِّغِ الشَّاهِدُ الْغَائِبَ، فَإِنَّ الشَّاهِدَ عَسَى أَنْ يُبَلِّغَ مَنْ هُوَ أَوْعَى لَهُ مِنْهُ ‏"‏‏.‏\hadithno{67}\hadithtrans{Narrated `Abdur-Rahman bin Abi Bakra's father:Once the Prophet (ﷺ) was riding his camel and a man was holding its rein. The Prophet (ﷺ) asked, "What is the day today?" We kept quiet, thinking that he might give that day another name. He said, "Isn't it the day of Nahr (slaughtering of the animals of sacrifice)" We replied, "Yes." He further asked, "Which month is this?" We again kept quiet, thinking that he might give it another name. Then he said, "Isn't it the month of Dhul-Hijja?" We replied, "Yes." He said, "Verily! Your blood, property and honor are sacred to one another (i.e. Muslims) like the sanctity of this day of yours, in this month of yours and in this city of yours. It is incumbent upon those who are present to inform those who are absent because those who are absent might comprehend (what I have said) better than the present audience}}
\hadithdefcmd{bukhari}{68}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنِ ابْنِ مَسْعُودٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَتَخَوَّلُنَا بِالْمَوْعِظَةِ فِي الأَيَّامِ، كَرَاهَةَ السَّآمَةِ عَلَيْنَا‏.‏\hadithno{68}\hadithtrans{Narrated Ibn Mas`ud:The Prophet (ﷺ) used to take care of us in preaching by selecting a suitable time, so that we might not get bored. (He abstained from pestering us with sermons and knowledge all the time)}}
\hadithdefcmd{bukhari}{69}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثَنِي أَبُو التَّيَّاحِ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ يَسِّرُوا وَلاَ تُعَسِّرُوا، وَبَشِّرُوا وَلاَ تُنَفِّرُوا ‏"‏‏.‏\hadithno{69}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) said, "Facilitate things to people (concerning religious matters), and do not make it hard for them and give them good tidings and do not make them run away (from Islam)}}
\hadithdefcmd{bukhari}{70}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، قَالَ كَانَ عَبْدُ اللَّهِ يُذَكِّرُ النَّاسَ فِي كُلِّ خَمِيسٍ، فَقَالَ لَهُ رَجُلٌ يَا أَبَا عَبْدِ الرَّحْمَنِ لَوَدِدْتُ أَنَّكَ ذَكَّرْتَنَا كُلَّ يَوْمٍ‏.‏ قَالَ أَمَا إِنَّهُ يَمْنَعُنِي مِنْ ذَلِكَ أَنِّي أَكْرَهُ أَنْ أُمِلَّكُمْ، وَإِنِّي أَتَخَوَّلُكُمْ بِالْمَوْعِظَةِ كَمَا كَانَ النَّبِيُّ صلى الله عليه وسلم يَتَخَوَّلُنَا بِهَا، مَخَافَةَ السَّآمَةِ عَلَيْنَا‏.‏\hadithno{70}\hadithtrans{Narrated Abu Wail:`Abdullah used to give a religious talk to the people on every Thursday. Once a man said, "O Aba `Abdur-Rahman! (By Allah) I wish if you could preach us daily." He replied, "The only thing which prevents me from doing so, is that I hate to bore you, and no doubt I take care of you in preaching by selecting a suitable time just as the Prophet (ﷺ) used to do with us, for fear of making us bored}}
\hadithdefcmd{bukhari}{71}{حَدَّثَنَا سَعِيدُ بْنُ عُفَيْرٍ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، قَالَ قَالَ حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ سَمِعْتُ مُعَاوِيَةَ، خَطِيبًا يَقُولُ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ يُرِدِ اللَّهُ بِهِ خَيْرًا يُفَقِّهْهُ فِي الدِّينِ، وَإِنَّمَا أَنَا قَاسِمٌ وَاللَّهُ يُعْطِي، وَلَنْ تَزَالَ هَذِهِ الأُمَّةُ قَائِمَةً عَلَى أَمْرِ اللَّهِ لاَ يَضُرُّهُمْ مَنْ خَالَفَهُمْ حَتَّى يَأْتِيَ أَمْرُ اللَّهِ ‏"‏‏.‏\hadithno{71}\hadithtrans{Narrated Muawiya:I heard Allah's Messenger (ﷺ) saying, "If Allah wants to do good to a person, He makes him comprehend the religion. I am just a distributor, but the grant is from Allah. (And remember) that this nation (true Muslims) will keep on following Allah's teachings strictly and they will not be harmed by any one going on a different path till Allah's order (Day of Judgment) is established}}
\hadithdefcmd{bukhari}{72}{حَدَّثَنَا عَلِيٌّ، حَدَّثَنَا سُفْيَانُ، قَالَ قَالَ لِي ابْنُ أَبِي نَجِيحٍ عَنْ مُجَاهِدٍ، قَالَ صَحِبْتُ ابْنَ عُمَرَ إِلَى الْمَدِينَةِ فَلَمْ أَسْمَعْهُ يُحَدِّثُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلاَّ حَدِيثًا وَاحِدًا، قَالَ كُنَّا عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَأُتِيَ بِجُمَّارٍ فَقَالَ ‏"‏ إِنَّ مِنَ الشَّجَرِ شَجَرَةً مَثَلُهَا كَمَثَلِ الْمُسْلِمِ ‏"‏‏.‏ فَأَرَدْتُ أَنْ أَقُولَ هِيَ النَّخْلَةُ، فَإِذَا أَنَا أَصْغَرُ الْقَوْمِ فَسَكَتُّ، قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ هِيَ النَّخْلَةُ ‏"‏‏.‏\hadithno{72}\hadithtrans{Narrated Ibn `Umar:We were with the Prophet (ﷺ) and fresh dates of a palm tree were brought to him. On that he said, "Amongst the trees, there is a tree which resembles a Muslim." I wanted to say that it was the datepalm tree but as I was the youngest of all (of them) I kept quiet. And then the Prophet (ﷺ) said, "It is the date-palm tree}}
\hadithdefcmd{bukhari}{73}{حَدَّثَنَا الْحُمَيْدِيُّ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنِي إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، عَلَى غَيْرِ مَا حَدَّثَنَاهُ الزُّهْرِيُّ، قَالَ سَمِعْتُ قَيْسَ بْنَ أَبِي حَازِمٍ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ مَسْعُودٍ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ حَسَدَ إِلاَّ فِي اثْنَتَيْنِ رَجُلٌ آتَاهُ اللَّهُ مَالاً فَسُلِّطَ عَلَى هَلَكَتِهِ فِي الْحَقِّ، وَرَجُلٌ آتَاهُ اللَّهُ الْحِكْمَةَ، فَهْوَ يَقْضِي بِهَا وَيُعَلِّمُهَا ‏"‏‏.‏\hadithno{73}\hadithtrans{Narrated `Abdullah bin Mas`ud:The Prophet (ﷺ) said, "Do not wish to be like anyone except in two cases. (The first is) A person, whom Allah has given wealth and he spends it righteously; (the second is) the one whom Allah has given wisdom (the Holy Qur'an) and he acts according to it and teaches it to others." (Fath-al-Bari page 177 Vol)}}
\hadithdefcmd{bukhari}{74}{حَدَّثَنَا مُحَمَّدُ بْنُ غُرَيْرٍ الزُّهْرِيُّ، قَالَ حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنِي أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، حَدَّثَ أَنَّ عُبَيْدَ اللَّهِ بْنَ عَبْدِ اللَّهِ أَخْبَرَهُ عَنِ ابْنِ عَبَّاسٍ، أَنَّهُ تَمَارَى هُوَ وَالْحُرُّ بْنُ قَيْسِ بْنِ حِصْنٍ الْفَزَارِيُّ فِي صَاحِبِ مُوسَى قَالَ ابْنُ عَبَّاسٍ هُوَ خَضِرٌ‏.‏ فَمَرَّ بِهِمَا أُبَىُّ بْنُ كَعْبٍ، فَدَعَاهُ ابْنُ عَبَّاسٍ فَقَالَ إِنِّي تَمَارَيْتُ أَنَا وَصَاحِبِي، هَذَا فِي صَاحِبِ مُوسَى الَّذِي سَأَلَ مُوسَى السَّبِيلَ إِلَى لُقِيِّهِ، هَلْ سَمِعْتَ النَّبِيَّ صلى الله عليه وسلم يَذْكُرُ شَأْنَهُ قَالَ نَعَمْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ بَيْنَمَا مُوسَى فِي مَلإٍ مِنْ بَنِي إِسْرَائِيلَ، جَاءَهُ رَجُلٌ فَقَالَ هَلْ تَعْلَمُ أَحَدًا أَعْلَمَ مِنْكَ قَالَ مُوسَى لاَ‏.‏ فَأَوْحَى اللَّهُ إِلَى مُوسَى بَلَى، عَبْدُنَا خَضِرٌ، فَسَأَلَ مُوسَى السَّبِيلَ إِلَيْهِ، فَجَعَلَ اللَّهُ لَهُ الْحُوتَ آيَةً، وَقِيلَ لَهُ إِذَا فَقَدْتَ الْحُوتَ فَارْجِعْ، فَإِنَّكَ سَتَلْقَاهُ، وَكَانَ يَتَّبِعُ أَثَرَ الْحُوتِ فِي الْبَحْرِ، فَقَالَ لِمُوسَى فَتَاهُ أَرَأَيْتَ إِذْ أَوَيْنَا إِلَى الصَّخْرَةِ فَإِنِّي نَسِيتُ الْحُوتَ، وَمَا أَنْسَانِيهِ إِلاَّ الشَّيْطَانُ أَنْ أَذْكُرَهُ‏.‏ قَالَ ذَلِكَ مَا كُنَّا نَبْغِي، فَارْتَدَّا عَلَى آثَارِهِمَا قَصَصًا، فَوَجَدَا خَضِرًا‏.‏ فَكَانَ مِنْ شَأْنِهِمَا الَّذِي قَصَّ اللَّهُ ـ عَزَّ وَجَلَّ ـ فِي كِتَابِهِ ‏"‏‏.‏\hadithno{74}\hadithtrans{Narrated Ibn `Abbas:That he differed with Hur bin Qais bin Hisn Al-Fazari regarding the companion of (the Prophet) Moses. Ibn `Abbas said that he was Al Khadir. Meanwhile, Ubai bin Ka`b passed by them and Ibn `Abbas called him, saying "My friend (Hur) and I have differed regarding Moses' companion, whom Moses asked the way to meet. Have you heard the Prophet (ﷺ) mentioning something about him? He said, "Yes. I heard Allah's Messenger (ﷺ) saying, "While Moses was sitting in the company of some Israelites, a man came and asked him. "Do you know anyone who is more learned than you? Moses replied: "No." So Allah sent the Divine Inspiration to Moses: 'Yes, Our slave Khadir (is more learned than you.)' Moses asked (Allah) how to meet him (Khadir). So Allah made the fish as a sign for him and he was told that when the fish was lost, he should return (to the place where he had lost it) and there he would meet him (Al-Khadir). So Moses went on looking for the sign of the fish in the sea. The servant-boy of Moses said to him: Do you remember when we betook ourselves to the rock, I indeed forgot the fish, none but Satan made me forget to remember it. On that Moses said: 'That is what we have been seeking' (18.64). So they went back retracing their footsteps, and found Khadir. (And) what happened further to them is narrated in the Holy Qur'an by Allah. (18.54 up to)}}
\hadithdefcmd{bukhari}{75}{حَدَّثَنَا أَبُو مَعْمَرٍ، قَالَ حَدَّثَنَا عَبْدُ الْوَارِثِ، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ ضَمَّنِي رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَالَ ‏ "‏ اللَّهُمَّ عَلِّمْهُ الْكِتَابَ ‏"‏‏.‏\hadithno{75}\hadithtrans{Narrated Ibn `Abbas:Once the Prophet (ﷺ) embraced me and said, "O Allah! Bestow on him the knowledge of the Book (Qur'an)}}
\hadithdefcmd{bukhari}{76}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي أُوَيْسٍ، قَالَ حَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، قَالَ أَقْبَلْتُ رَاكِبًا عَلَى حِمَارٍ أَتَانٍ، وَأَنَا يَوْمَئِذٍ قَدْ نَاهَزْتُ الاِحْتِلاَمَ، وَرَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي بِمِنًى إِلَى غَيْرِ جِدَارٍ، فَمَرَرْتُ بَيْنَ يَدَىْ بَعْضِ الصَّفِّ وَأَرْسَلْتُ الأَتَانَ تَرْتَعُ، فَدَخَلْتُ فِي الصَّفِّ، فَلَمْ يُنْكَرْ ذَلِكَ عَلَىَّ‏.‏\hadithno{76}\hadithtrans{Narrated Ibn `Abbas:Once I came riding a she-ass and had (just) attained the age of puberty. Allah's Messenger (ﷺ) was offering the prayer at Mina. There was no wall in front of him and I passed in front of some of the row while they were offering their prayers. There I let the she-ass loose to graze and entered the row, and nobody objected to it}}
\hadithdefcmd{bukhari}{77}{حَدَّثَنِي مُحَمَّدُ بْنُ يُوسُفَ، قَالَ حَدَّثَنَا أَبُو مُسْهِرٍ، قَالَ حَدَّثَنِي مُحَمَّدُ بْنُ حَرْبٍ، حَدَّثَنِي الزُّبَيْدِيُّ، عَنِ الزُّهْرِيِّ، عَنْ مَحْمُودِ بْنِ الرَّبِيعِ، قَالَ عَقَلْتُ مِنَ النَّبِيِّ صلى الله عليه وسلم مَجَّةً مَجَّهَا فِي وَجْهِي وَأَنَا ابْنُ خَمْسِ سِنِينَ مِنْ دَلْوٍ‏.‏\hadithno{77}\hadithtrans{Narrated Mahmud bin Rabi`a:When I was a boy of five, I remember, the Prophet (ﷺ) took water from a bucket (used for getting water out of a well) with his mouth and threw it on my face}}
\hadithdefcmd{bukhari}{78}{حَدَّثَنَا أَبُو الْقَاسِمِ، خَالِدُ بْنُ خَلِيٍّ قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ حَرْبٍ، قَالَ قَالَ الأَوْزَاعِيُّ أَخْبَرَنَا الزُّهْرِيُّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّهُ تَمَارَى هُوَ وَالْحُرُّ بْنُ قَيْسِ بْنِ حِصْنٍ الْفَزَارِيُّ فِي صَاحِبِ مُوسَى، فَمَرَّ بِهِمَا أُبَىُّ بْنُ كَعْبٍ، فَدَعَاهُ ابْنُ عَبَّاسٍ فَقَالَ إِنِّي تَمَارَيْتُ أَنَا وَصَاحِبِي هَذَا فِي صَاحِبِ مُوسَى الَّذِي سَأَلَ السَّبِيلَ إِلَى لُقِيِّهِ، هَلْ سَمِعْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَذْكُرُ شَأْنَهُ فَقَالَ أُبَىٌّ نَعَمْ، سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَذْكُرُ شَأْنَهُ يَقُولُ ‏ "‏ بَيْنَمَا مُوسَى فِي مَلإٍ مِنْ بَنِي إِسْرَائِيلَ، إِذْ جَاءَهُ رَجُلٌ فَقَالَ أَتَعْلَمُ أَحَدًا أَعْلَمَ مِنْكَ قَالَ مُوسَى لاَ‏.‏ فَأَوْحَى اللَّهُ عَزَّ وَجَلَّ إِلَى مُوسَى بَلَى، عَبْدُنَا خَضِرٌ، فَسَأَلَ السَّبِيلَ إِلَى لُقِيِّهِ، فَجَعَلَ اللَّهُ لَهُ الْحُوتَ آيَةً، وَقِيلَ لَهُ إِذَا فَقَدْتَ الْحُوتَ فَارْجِعْ، فَإِنَّكَ سَتَلْقَاهُ، فَكَانَ مُوسَى صلى الله عليه وسلم يَتَّبِعُ أَثَرَ الْحُوتِ فِي الْبَحْرِ‏.‏ فَقَالَ فَتَى مُوسَى لِمُوسَى أَرَأَيْتَ إِذْ أَوَيْنَا إِلَى الصَّخْرَةِ فَإِنِّي نَسِيتُ الْحُوتَ، وَمَا أَنْسَانِيهِ إِلاَّ الشَّيْطَانُ أَنْ أَذْكُرَهُ‏.‏ قَالَ مُوسَى ذَلِكَ مَا كُنَّا نَبْغِي‏.‏ فَارْتَدَّا عَلَى آثَارِهِمَا قَصَصًا، فَوَجَدَا خَضِرًا، فَكَانَ مِنْ شَأْنِهِمَا مَا قَصَّ اللَّهُ فِي كِتَابِهِ ‏"‏‏.‏\hadithno{78}\hadithtrans{Narrated Ibn `Abbas:that he differed with Hur bin Qais bin Hisn Al-Fazari regarding the companion of the Prophet Moses (ﷺ). Meanwhile, Ubai bin Ka`b passed by them and Ibn `Abbas called him saying, "My friend (Hur) and I have differed regarding Moses' companion whom Moses asked the way to meet. Have you heard Allah's Messenger (ﷺ) mentioning something about him?" Ubai bin Ka`b said: "Yes, I heard the Prophet (ﷺ) mentioning something about him (saying) while Moses was sitting in the company of some Israelites, a man came and asked him: "Do you know anyone who is more learned than you?" Moses replied: "No." So Allah sent the Divine Inspiration to Moses: '--Yes, Our slave Khadir is more learned than you.' Moses asked Allah how to meet him (Al-Khadir). So Allah made the fish a sign for him and he was told when the fish was lost, he should return (to the place where he had lost it) and there he would meet him (Al-Khadir). So Moses went on looking for the sign of the fish in the sea. The servant-boy of Moses said: 'Do you remember when we betook ourselves to the rock, I indeed forgot the fish, none but Satan made me forget to remember it. On that Moses said, 'That is what we have been seeking.' So they went back retracing their footsteps, and found Khadir. (and) what happened further about them is narrated in the Holy Qur'an by Allah." (18.54 up to)}}
\hadithdefcmd{bukhari}{79}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ أُسَامَةَ، عَنْ بُرَيْدِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَثَلُ مَا بَعَثَنِي اللَّهُ بِهِ مِنَ الْهُدَى وَالْعِلْمِ كَمَثَلِ الْغَيْثِ الْكَثِيرِ أَصَابَ أَرْضًا، فَكَانَ مِنْهَا نَقِيَّةٌ قَبِلَتِ الْمَاءَ، فَأَنْبَتَتِ الْكَلأَ وَالْعُشْبَ الْكَثِيرَ، وَكَانَتْ مِنْهَا أَجَادِبُ أَمْسَكَتِ الْمَاءَ، فَنَفَعَ اللَّهُ بِهَا النَّاسَ، فَشَرِبُوا وَسَقَوْا وَزَرَعُوا، وَأَصَابَتْ مِنْهَا طَائِفَةً أُخْرَى، إِنَّمَا هِيَ قِيعَانٌ لاَ تُمْسِكُ مَاءً، وَلاَ تُنْبِتُ كَلأً، فَذَلِكَ مَثَلُ مَنْ فَقِهَ فِي دِينِ اللَّهِ وَنَفَعَهُ مَا بَعَثَنِي اللَّهُ بِهِ، فَعَلِمَ وَعَلَّمَ، وَمَثَلُ مَنْ لَمْ يَرْفَعْ بِذَلِكَ رَأْسًا، وَلَمْ يَقْبَلْ هُدَى اللَّهِ الَّذِي أُرْسِلْتُ بِهِ ‏"‏‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ قَالَ إِسْحَاقُ وَكَانَ مِنْهَا طَائِفَةٌ قَيَّلَتِ الْمَاءَ‏.‏ قَاعٌ يَعْلُوهُ الْمَاءُ، وَالصَّفْصَفُ الْمُسْتَوِي مِنَ الأَرْضِ‏.‏\hadithno{79}\hadithtrans{Narrated Abu Musa:The Prophet (ﷺ) said, "The example of guidance and knowledge with which Allah has sent me is like abundant rain falling on the earth, some of which was fertile soil that absorbed rain water and brought forth vegetation and grass in abundance. (And) another portion of it was hard and held the rain water and Allah benefited the people with it and they utilized it for drinking, making their animals drink from it and for irrigation of the land for cultivation. (And) a portion of it was barren which could neither hold the water nor bring forth vegetation (then that land gave no benefits). The first is the example of the person who comprehends Allah's religion and gets benefit (from the knowledge) which Allah has revealed through me (the Prophet) and learns and then teaches others. The last example is that of a person who does not care for it and does not take Allah's guidance revealed through me (He is like that barren land)}}
\hadithdefcmd{bukhari}{80}{حَدَّثَنَا عِمْرَانُ بْنُ مَيْسَرَةَ، قَالَ حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ أَبِي التَّيَّاحِ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ مِنْ أَشْرَاطِ السَّاعَةِ أَنْ يُرْفَعَ الْعِلْمُ، وَيَثْبُتَ الْجَهْلُ، وَيُشْرَبَ الْخَمْرُ، وَيَظْهَرَ الزِّنَا ‏"‏‏.‏\hadithno{80}\hadithtrans{Narrated Anas:Allah's Messenger (ﷺ) said, "From among the portents of the Hour are (the following): -1. Religious knowledge will be taken away (by the death of Religious learned men). -2. (Religious) ignorance will prevail. -3. Drinking of Alcoholic drinks (will be very common). -4. There will be prevalence of open illegal sexual intercourse}}
\hadithdefcmd{bukhari}{81}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ لأُحَدِّثَنَّكُمْ حَدِيثًا لاَ يُحَدِّثُكُمْ أَحَدٌ بَعْدِي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مِنْ أَشْرَاطِ السَّاعَةِ أَنْ يَقِلَّ الْعِلْمُ، وَيَظْهَرَ الْجَهْلُ، وَيَظْهَرَ الزِّنَا، وَتَكْثُرَ النِّسَاءُ وَيَقِلَّ الرِّجَالُ، حَتَّى يَكُونَ لِخَمْسِينَ امْرَأَةً الْقَيِّمُ الْوَاحِدُ ‏"‏‏.‏\hadithno{81}\hadithtrans{Narrated Anas:I will narrate to you a Hadith and none other than I will tell you about after it. I heard Allah's Messenger (ﷺ) saying: From among the portents of the Hour are (the following): -1. Religious knowledge will decrease (by the death of religious learned men). -2. Religious ignorance will prevail. -3. There will be prevalence of open illegal sexual intercourse. -4. Women will increase in number and men will decrease in number so much so that fifty women will be looked after by one man}}
\hadithdefcmd{bukhari}{82}{حَدَّثَنَا سَعِيدُ بْنُ عُفَيْرٍ، قَالَ حَدَّثَنِي اللَّيْثُ، قَالَ حَدَّثَنِي عُقَيْلٌ، عَنِ ابْنِ شِهَابٍ، عَنْ حَمْزَةَ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ ابْنَ عُمَرَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ بَيْنَا أَنَا نَائِمٌ أُتِيتُ بِقَدَحِ لَبَنٍ، فَشَرِبْتُ حَتَّى إِنِّي لأَرَى الرِّيَّ يَخْرُجُ فِي أَظْفَارِي، ثُمَّ أَعْطَيْتُ فَضْلِي عُمَرَ بْنَ الْخَطَّابِ ‏"‏‏.‏ قَالُوا فَمَا أَوَّلْتَهُ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ الْعِلْمَ ‏"‏‏.‏\hadithno{82}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) said, "While I was sleeping, I saw that a cup full of milk was brought to me and I drank my fill till I noticed (the milk) its wetness coming out of my nails. Then I gave the remaining milk to `Umar Ibn Al-Khattab" The companions of the Prophet (ﷺ) asked, "What have you interpreted (about this dream), O Allah's Messenger (ﷺ)?" He replied, "(It is religious) knowledge}}
\hadithdefcmd{bukhari}{83}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عِيسَى بْنِ طَلْحَةَ بْنِ عُبَيْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم وَقَفَ فِي حَجَّةِ الْوَدَاعِ بِمِنًى لِلنَّاسِ يَسْأَلُونَهُ، فَجَاءَهُ رَجُلٌ فَقَالَ لَمْ أَشْعُرْ فَحَلَقْتُ قَبْلَ أَنْ أَذْبَحَ‏.‏ فَقَالَ ‏"‏ اذْبَحْ وَلاَ حَرَجَ ‏"‏‏.‏ فَجَاءَ آخَرُ فَقَالَ لَمْ أَشْعُرْ، فَنَحَرْتُ قَبْلَ أَنْ أَرْمِيَ‏.‏ قَالَ ‏"‏ ارْمِ وَلاَ حَرَجَ ‏"‏‏.‏ فَمَا سُئِلَ النَّبِيُّ صلى الله عليه وسلم عَنْ شَىْءٍ قُدِّمَ وَلاَ أُخِّرَ إِلاَّ قَالَ افْعَلْ وَلاَ حَرَجَ‏.‏\hadithno{83}\hadithtrans{Narrated `Abdullah bin `Amr bin Al `Aas:Allah's Messenger (ﷺ) stopped (for a while near the Jimar) at Mina during his last Hajj for the people and they were asking him questions. A man came and said, "I forgot and got my head shaved before slaughtering the Hadi (sacrificing animal)." The Prophet (ﷺ) said, "There is no harm, go and do the slaughtering now." Then another person came and said, "I forgot and slaughtered (the camel) before Rami (throwing of the pebbles) at the Jamra." The Prophet (ﷺ) said, "Do the Rami now and there is no harm." The narrator added: So on that day, when the Prophet (ﷺ) was asked about anything (as regards the ceremonies of Hajj) performed before or after its due time, his reply was: "Do it (now) and there is no harm}}
\hadithdefcmd{bukhari}{84}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا وُهَيْبٌ، قَالَ حَدَّثَنَا أَيُّوبُ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم سُئِلَ فِي حَجَّتِهِ فَقَالَ ذَبَحْتُ قَبْلَ أَنْ أَرْمِيَ، فَأَوْمَأَ بِيَدِهِ قَالَ وَلاَ حَرَجَ‏.‏ قَالَ حَلَقْتُ قَبْلَ أَنْ أَذْبَحَ‏.‏ فَأَوْمَأَ بِيَدِهِ وَلاَ حَرَجَ‏.‏\hadithno{84}\hadithtrans{Narrated Ibn `Abbas:Somebody said to the Prophet (during his last Hajj), "I did the slaughtering before doing the Rami.' The Prophet (ﷺ) beckoned with his hand and said, "There is no harm in that." Then another person said, "I got my head shaved before offering the sacrifice." The Prophet (ﷺ) beckoned with his hand saying, "There is no harm in that}}
\hadithdefcmd{bukhari}{85}{حَدَّثَنَا الْمَكِّيُّ بْنُ إِبْرَاهِيمَ، قَالَ أَخْبَرَنَا حَنْظَلَةُ بْنُ أَبِي سُفْيَانَ، عَنْ سَالِمٍ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ يُقْبَضُ الْعِلْمُ، وَيَظْهَرُ الْجَهْلُ وَالْفِتَنُ، وَيَكْثُرُ الْهَرْجُ ‏"‏‏.‏ قِيلَ يَا رَسُولَ اللَّهِ وَمَا الْهَرْجُ فَقَالَ هَكَذَا بِيَدِهِ، فَحَرَّفَهَا، كَأَنَّهُ يُرِيدُ الْقَتْلَ‏.‏\hadithno{85}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "(Religious) knowledge will be taken away (by the death of religious scholars) ignorance (in religion) and afflictions will appear; and Harj will increase." It was asked, "What is Harj, O Allah's Messenger (ﷺ)?" He replied by beckoning with his hand indicating "killing." (Fath-al-Bari Page 192, Vol)}}
\hadithdefcmd{bukhari}{86}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا وُهَيْبٌ، قَالَ حَدَّثَنَا هِشَامٌ، عَنْ فَاطِمَةَ، عَنْ أَسْمَاءَ، قَالَتْ أَتَيْتُ عَائِشَةَ وَهِيَ تُصَلِّي فَقُلْتُ مَا شَأْنُ النَّاسِ فَأَشَارَتْ إِلَى السَّمَاءِ، فَإِذَا النَّاسُ قِيَامٌ، فَقَالَتْ سُبْحَانَ اللَّهِ‏.‏ قُلْتُ آيَةٌ فَأَشَارَتْ بِرَأْسِهَا، أَىْ نَعَمْ، فَقُمْتُ حَتَّى تَجَلاَّنِي الْغَشْىُ، فَجَعَلْتُ أَصُبُّ عَلَى رَأْسِي الْمَاءَ، فَحَمِدَ اللَّهَ عَزَّ وَجَلَّ النَّبِيُّ صلى الله عليه وسلم وَأَثْنَى عَلَيْهِ، ثُمَّ قَالَ ‏ "‏ مَا مِنْ شَىْءٍ لَمْ أَكُنْ أُرِيتُهُ إِلاَّ رَأَيْتُهُ فِي مَقَامِي حَتَّى الْجَنَّةَ وَالنَّارَ، فَأُوحِيَ إِلَىَّ أَنَّكُمْ تُفْتَنُونَ فِي قُبُورِكُمْ، مِثْلَ ـ أَوْ قَرِيبًا لاَ أَدْرِي أَىَّ ذَلِكَ قَالَتْ أَسْمَاءُ ـ مِنْ فِتْنَةِ الْمَسِيحِ الدَّجَّالِ، يُقَالُ مَا عِلْمُكَ بِهَذَا الرَّجُلِ فَأَمَّا الْمُؤْمِنُ ـ أَوِ الْمُوقِنُ لاَ أَدْرِي بِأَيِّهِمَا قَالَتْ أَسْمَاءُ ـ فَيَقُولُ هُوَ مُحَمَّدٌ رَسُولُ اللَّهِ جَاءَنَا بِالْبَيِّنَاتِ وَالْهُدَى، فَأَجَبْنَا وَاتَّبَعْنَا، هُوَ مُحَمَّدٌ‏.‏ ثَلاَثًا، فَيُقَالُ نَمْ صَالِحًا، قَدْ عَلِمْنَا إِنْ كُنْتَ لَمُوقِنًا بِهِ، وَأَمَّا الْمُنَافِقُ ـ أَوِ الْمُرْتَابُ لاَ أَدْرِي أَىَّ ذَلِكَ قَالَتْ أَسْمَاءُ ـ فَيَقُولُ لاَ أَدْرِي، سَمِعْتُ النَّاسَ يَقُولُونَ شَيْئًا فَقُلْتُهُ ‏"‏‏.‏\hadithno{86}\hadithtrans{Narrated Asma':I came to `Aisha while she was praying, and said to her, "What has happened to the people?" She pointed out towards the sky. (I looked towards the mosque), and saw the people offering the prayer. Aisha said, "Subhan Allah." I said to her, "Is there a sign?" She nodded with her head meaning, "Yes." I, too, then stood (for the prayer of eclipse) till I became (nearly) unconscious and later on I poured water on my head. After the prayer, the Prophet (ﷺ) praised and glorified Allah and then said, "Just now at this place I have seen what I have never seen before, including Paradise and Hell. No doubt it has been inspired to me that you will be put to trials in your graves and these trials will be like the trials of Masih-ad-Dajjal or nearly like it (the sub narrator is not sure which expression Asma' used). You will be asked, 'What do you know about this man (the Prophet Muhammad (ﷺ))?' Then the faithful believer (or Asma' said a similar word) will reply, 'He is Muhammad Allah's Messenger (ﷺ) who had come to us with clear evidences and guidance and so we accepted his teachings and followed him. And he is Muhammad.' And he will repeat it thrice. Then the angels will say to him, 'Sleep in peace as we have come to know that you were a faithful believer.' On the other hand, a hypocrite or a doubtful person will reply, 'I do not know, but I heard the people saying something and so I said it.' (the same)}}
\hadithdefcmd{bukhari}{87}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا غُنْدَرٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي جَمْرَةَ، قَالَ كُنْتُ أُتَرْجِمُ بَيْنَ ابْنِ عَبَّاسٍ وَبَيْنَ النَّاسِ فَقَالَ إِنَّ وَفْدَ عَبْدِ الْقَيْسِ أَتَوُا النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏"‏ مَنِ الْوَفْدُ ـ أَوْ مَنِ الْقَوْمُ ‏"‏‏.‏ قَالُوا رَبِيعَةُ‏.‏ فَقَالَ ‏"‏ مَرْحَبًا بِالْقَوْمِ ـ أَوْ بِالْوَفْدِ ـ غَيْرَ خَزَايَا وَلاَ نَدَامَى ‏"‏‏.‏ قَالُوا إِنَّا نَأْتِيكَ مِنْ شُقَّةٍ بَعِيدَةٍ، وَبَيْنَنَا وَبَيْنَكَ هَذَا الْحَىُّ مِنْ كُفَّارِ مُضَرَ، وَلاَ نَسْتَطِيعُ أَنْ نَأْتِيَكَ إِلاَّ فِي شَهْرٍ حَرَامٍ فَمُرْنَا بِأَمْرٍ نُخْبِرْ بِهِ مَنْ وَرَاءَنَا، نَدْخُلُ بِهِ الْجَنَّةَ‏.‏ فَأَمَرَهُمْ بِأَرْبَعٍ، وَنَهَاهُمْ عَنْ أَرْبَعٍ أَمَرَهُمْ بِالإِيمَانِ بِاللَّهِ عَزَّ وَجَلَّ وَحْدَهُ‏.‏ قَالَ ‏"‏ هَلْ تَدْرُونَ مَا الإِيمَانُ بِاللَّهِ وَحْدَهُ ‏"‏‏.‏ قَالُوا اللَّهُ وَرَسُولُهُ أَعْلَمُ‏.‏ قَالَ ‏"‏ شَهَادَةُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنَّ مُحَمَّدًا رَسُولُ اللَّهِ، وَإِقَامُ الصَّلاَةِ، وَإِيتَاءُ الزَّكَاةِ، وَصَوْمُ رَمَضَانَ، وَتُعْطُوا الْخُمُسَ مِنَ الْمَغْنَمِ ‏"‏‏.‏ وَنَهَاهُمْ عَنِ الدُّبَّاءِ وَالْحَنْتَمِ وَالْمُزَفَّتِ‏.‏ قَالَ شُعْبَةُ رُبَّمَا قَالَ النَّقِيرِ، وَرُبَّمَا قَالَ الْمُقَيَّرِ‏.‏ قَالَ ‏"‏ احْفَظُوهُ وَأَخْبِرُوهُ مَنْ وَرَاءَكُمْ ‏"‏‏.‏\hadithno{87}\hadithtrans{Narrated Abu Jamra:I was an interpreter between the people and Ibn `Abbas. Once Ibn `Abbas said that a delegation of the tribe of `Abdul Qais came to the Prophet (ﷺ) who asked them, "Who are the people (i.e. you)? (Or) who are the delegates?" They replied, "We are from the tribe of Rabi`a." Then the Prophet (ﷺ) said to them, "Welcome, O people (or said, "O delegation (of `Abdul Qais).") Neither will you have disgrace nor will you regret." They said, "We have come to you from a distant place and there is the tribe of the infidels of Mudar intervening between you and us and we cannot come to you except in the sacred month. So please order us to do something good (religious deeds) and that we may also inform our people whom we have left behind (at home) and that we may enter Paradise (by acting on them.)" The Prophet ordered them to do four things, and forbade them from four things. He ordered them to believe in Allah Alone, the Honorable the Majestic and said to them, "Do you know what is meant by believing in Allah Alone?" They replied, "Allah and His Apostle know better." Thereupon the Prophet (ﷺ) said, "(That means to testify that none has the right to be worshipped but Allah and that Muhammad is His Apostle, to offer prayers perfectly, to pay Zakat, to observe fasts during the month of Ramadan, (and) to pay Al-Khumus (one fifth of the booty to be given in Allah's cause)." Then he forbade them four things, namely Ad-Dubba.' Hantam, Muzaffat (and) An-Naqir or Muqaiyar (These were the names of pots in which alcoholic drinks used to be prepared). The Prophet (ﷺ) further said, "Memorize them (these instructions) and tell them to the people whom you have left behind}}
\hadithdefcmd{bukhari}{88}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ أَبُو الْحَسَنِ، قَالَ أَخْبَرَنَا عَبْدُ اللَّهِ، قَالَ أَخْبَرَنَا عُمَرُ بْنُ سَعِيدِ بْنِ أَبِي حُسَيْنٍ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ أَبِي مُلَيْكَةَ، عَنْ عُقْبَةَ بْنِ الْحَارِثِ، أَنَّهُ تَزَوَّجَ ابْنَةً لأَبِي إِهَابِ بْنِ عَزِيزٍ، فَأَتَتْهُ امْرَأَةٌ فَقَالَتْ إِنِّي قَدْ أَرْضَعْتُ عُقْبَةَ وَالَّتِي تَزَوَّجَ بِهَا‏.‏ فَقَالَ لَهَا عُقْبَةُ مَا أَعْلَمُ أَنَّكِ أَرْضَعْتِنِي وَلاَ أَخْبَرْتِنِي‏.‏ فَرَكِبَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم بِالْمَدِينَةِ فَسَأَلَهُ، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كَيْفَ وَقَدْ قِيلَ ‏"‏‏.‏ فَفَارَقَهَا عُقْبَةُ، وَنَكَحَتْ زَوْجًا غَيْرَهُ‏.‏\hadithno{88}\hadithtrans{Narrated `Abdullah bin Abi Mulaika:`Uqba bin Al-Harith said that he had married the daughter of Abi Ihab bin `Aziz. Later on a woman came to him and said, "I have suckled (nursed) `Uqba and the woman whom he married (his wife) at my breast." `Uqba said to her, "Neither I knew that you have suckled (nursed) me nor did you tell me." Then he rode over to see Allah's Messenger (ﷺ) at Medina, and asked him about it. Allah's Messenger (ﷺ) said, "How can you keep her as a wife when it has been said (that she is your foster-sister)?" Then `Uqba divorced her, and she married another man}}
\hadithdefcmd{bukhari}{89}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، ح قَالَ أَبُو عَبْدِ اللَّهِ وَقَالَ ابْنُ وَهْبٍ أَخْبَرَنَا يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي ثَوْرٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، عَنْ عُمَرَ، قَالَ كُنْتُ أَنَا وَجَارٌ، لِي مِنَ الأَنْصَارِ فِي بَنِي أُمَيَّةَ بْنِ زَيْدٍ، وَهْىَ مِنْ عَوَالِي الْمَدِينَةِ، وَكُنَّا نَتَنَاوَبُ النُّزُولَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم يَنْزِلُ يَوْمًا وَأَنْزِلُ يَوْمًا، فَإِذَا نَزَلْتُ جِئْتُهُ بِخَبَرِ ذَلِكَ الْيَوْمِ مِنَ الْوَحْىِ وَغَيْرِهِ، وَإِذَا نَزَلَ فَعَلَ مِثْلَ ذَلِكَ، فَنَزَلَ صَاحِبِي الأَنْصَارِيُّ يَوْمَ نَوْبَتِهِ، فَضَرَبَ بَابِي ضَرْبًا شَدِيدًا‏.‏ فَقَالَ أَثَمَّ هُوَ فَفَزِعْتُ فَخَرَجْتُ إِلَيْهِ فَقَالَ قَدْ حَدَثَ أَمْرٌ عَظِيمٌ‏.‏ قَالَ فَدَخَلْتُ عَلَى حَفْصَةَ فَإِذَا هِيَ تَبْكِي فَقُلْتُ طَلَّقَكُنَّ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَتْ لاَ أَدْرِي‏.‏ ثُمَّ دَخَلْتُ عَلَى النَّبِيِّ صلى الله عليه وسلم فَقُلْتُ وَأَنَا قَائِمٌ أَطَلَّقْتَ نِسَاءَكَ قَالَ ‏ "‏ لاَ ‏"‏‏.‏ فَقُلْتُ اللَّهُ أَكْبَرُ‏.‏\hadithno{89}\hadithtrans{Narrated `Umar:My Ansari neighbor from Bani Umaiya bin Zaid who used to live at `Awali Al-Medina and I used to visit the Prophet (ﷺ) by turns. He used to go one day and I another day. When I went I used to bring the news of that day regarding the Divine Inspiration and other things, and when he went, he used to do the same for me. Once my Ansari friend, in his turn (on returning from the Prophet), knocked violently at my door and asked if I was there." I became horrified and came out to him. He said, "Today a great thing has happened." I then went to Hafsa and saw her weeping. I asked her, "Did Allah's Messenger (ﷺ) divorce you all?" She replied, "I do not know." Then, I entered upon the Prophet (ﷺ) and said while standing, "Have you divorced your wives?" The Prophet (ﷺ) replied in the negative. On that I said, "Allahu-Akbar (Allah is Greater)." (See Hadith No. 119, Vol. 3 for details)}}
\hadithdefcmd{bukhari}{90}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، قَالَ أَخْبَرَنَا سُفْيَانُ، عَنِ ابْنِ أَبِي خَالِدٍ، عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، عَنْ أَبِي مَسْعُودٍ الأَنْصَارِيِّ، قَالَ قَالَ رَجُلٌ يَا رَسُولَ اللَّهِ، لاَ أَكَادُ أُدْرِكُ الصَّلاَةَ مِمَّا يُطَوِّلُ بِنَا فُلاَنٌ، فَمَا رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم فِي مَوْعِظَةٍ أَشَدَّ غَضَبًا مِنْ يَوْمِئِذٍ فَقَالَ ‏ "‏ أَيُّهَا النَّاسُ، إِنَّكُمْ مُنَفِّرُونَ، فَمَنْ صَلَّى بِالنَّاسِ فَلْيُخَفِّفْ، فَإِنَّ فِيهِمُ الْمَرِيضَ وَالضَّعِيفَ وَذَا الْحَاجَةِ ‏"‏‏.‏\hadithno{90}\hadithtrans{Narrated Abu Mas`ud Al-Ansari:Once a man said to Allah's Messenger (ﷺ) "O Allah's Messenger (ﷺ)! I may not attend the (compulsory congregational) prayer because so and so (the Imam) prolongs the prayer when he leads us for it. The narrator added: "I never saw the Prophet (ﷺ) more furious in giving advice than he was on that day. The Prophet said, "O people! Some of you make others dislike good deeds (the prayers). So whoever leads the people in prayer should shorten it because among them there are the sick the weak and the needy (having some jobs to do)}}
\hadithdefcmd{bukhari}{91}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا أَبُو عَامِرٍ، قَالَ حَدَّثَنَا سُلَيْمَانُ بْنُ بِلاَلٍ الْمَدِينِيُّ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ يَزِيدَ، مَوْلَى الْمُنْبَعِثِ عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم سَأَلَهُ رَجُلٌ عَنِ اللُّقَطَةِ فَقَالَ ‏"‏ اعْرِفْ وِكَاءَهَا ـ أَوْ قَالَ وِعَاءَهَا ـ وَعِفَاصَهَا، ثُمَّ عَرِّفْهَا سَنَةً، ثُمَّ اسْتَمْتِعْ بِهَا، فَإِنْ جَاءَ رَبُّهَا فَأَدِّهَا إِلَيْهِ ‏"‏‏.‏ قَالَ فَضَالَّةُ الإِبِلِ فَغَضِبَ حَتَّى احْمَرَّتْ وَجْنَتَاهُ ـ أَوْ قَالَ احْمَرَّ وَجْهُهُ ـ فَقَالَ ‏"‏ وَمَا لَكَ وَلَهَا مَعَهَا سِقَاؤُهَا وَحِذَاؤُهَا، تَرِدُ الْمَاءَ، وَتَرْعَى الشَّجَرَ، فَذَرْهَا حَتَّى يَلْقَاهَا رَبُّهَا ‏"‏‏.‏ قَالَ فَضَالَّةُ الْغَنَمِ قَالَ ‏"‏ لَكَ أَوْ لأَخِيكَ أَوْ لِلذِّئْبِ ‏"‏‏.‏\hadithno{91}\hadithtrans{Narrated Zaid bin Khalid Al-Juhani:A man asked the Prophet (ﷺ) about the picking up of a "Luqata" (fallen lost thing). The Prophet (ﷺ) replied, "Recognize and remember its tying material and its container, and make public announcement (about it) for one year, then utilize it but give it to its owner if he comes." Then the person asked about the lost camel. On that, the Prophet (ﷺ) got angry and his cheeks or his Face became red and he said, "You have no concern with it as it has its water container, and its feet and it will reach water, and eat (the leaves) of trees till its owner finds it." The man then asked about the lost sheep. The Prophet (ﷺ) replied, "It is either for you, for your brother (another person) or for the wolf}}
\hadithdefcmd{bukhari}{92}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، قَالَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ سُئِلَ النَّبِيُّ صلى الله عليه وسلم عَنْ أَشْيَاءَ كَرِهَهَا، فَلَمَّا أُكْثِرَ عَلَيْهِ غَضِبَ، ثُمَّ قَالَ لِلنَّاسِ ‏"‏ سَلُونِي عَمَّا شِئْتُمْ ‏"‏‏.‏ قَالَ رَجُلٌ مَنْ أَبِي قَالَ ‏"‏ أَبُوكَ حُذَافَةُ ‏"‏‏.‏ فَقَامَ آخَرُ فَقَالَ مَنْ أَبِي يَا رَسُولَ اللَّهِ فَقَالَ ‏"‏ أَبُوكَ سَالِمٌ مَوْلَى شَيْبَةَ ‏"‏‏.‏ فَلَمَّا رَأَى عُمَرُ مَا فِي وَجْهِهِ قَالَ يَا رَسُولَ اللَّهِ، إِنَّا نَتُوبُ إِلَى اللَّهِ عَزَّ وَجَلَّ‏.‏\hadithno{92}\hadithtrans{Narrated Abu Musa:The Prophet (ﷺ) was asked about things which he did not like, but when the questioners insisted, the Prophet got angry. He then said to the people, "Ask me anything you like." A man asked, "Who is my father?" The Prophet (ﷺ) replied, "Your father is Hudhafa." Then another man got up and said, "Who is my father, O Allah's Messenger (ﷺ) ?" He replied, "Your father is Salim, Maula (the freed slave) of Shaiba." So when `Umar saw that (the anger) on the face of the Prophet (ﷺ) he said, "O Allah's Messenger (ﷺ)! We repent to Allah (Our offending you)}}
\hadithdefcmd{bukhari}{93}{حَدَّثَنَا أَبُو الْيَمَانِ، قَالَ أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي أَنَسُ بْنُ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ، فَقَامَ عَبْدُ اللَّهِ بْنُ حُذَافَةَ فَقَالَ مَنْ أَبِي فَقَالَ ‏"‏ أَبُوكَ حُذَافَةُ ‏"‏‏.‏ ثُمَّ أَكْثَرَ أَنْ يَقُولَ ‏"‏ سَلُونِي ‏"‏‏.‏ فَبَرَكَ عُمَرُ عَلَى رُكْبَتَيْهِ فَقَالَ رَضِينَا بِاللَّهِ رَبًّا، وَبِالإِسْلاَمِ دِينًا، وَبِمُحَمَّدٍ صلى الله عليه وسلم نَبِيًّا، فَسَكَتَ‏.‏\hadithno{93}\hadithtrans{Narrated Anas bin Malik:One day Allah's Messenger (ﷺ) came out (before the people) and `Abdullah bin Hudhafa stood up and asked (him) "Who is my father?" The Prophet (ﷺ) replied, "Your father is Hudhafa." The Prophet (ﷺ) told them repeatedly (in anger) to ask him anything they liked. `Umar knelt down before the Prophet (ﷺ) and said thrice, "We accept Allah as (our) Lord and Islam as (our) religion and Muhammad as (our) Prophet." After that the Prophet (ﷺ) became silent}}
\hadithdefcmd{bukhari}{94}{حَدَّثَنَا عَبْدَةُ، قَالَ حَدَّثَنَا عَبْدُ الصَّمَدِ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا ثُمَامَةُ بْنُ عَبْدِ اللَّهِ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَانَ إِذَا سَلَّمَ سَلَّمَ ثَلاَثًا، وَإِذَا تَكَلَّمَ بِكَلِمَةٍ أَعَادَهَا ثَلاَثًا‏.‏\hadithno{94}\hadithtrans{Narrated Anas:Whenever the Prophet (ﷺ) asked permission to enter, he knocked the door thrice with greeting and whenever he spoke a sentence (said a thing) he used to repeat it thrice. (See Hadith No. 261, Vol)}}
\hadithdefcmd{bukhari}{95}{حَدَّثَنَا عَبْدَةُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا عَبْدُ الصَّمَدِ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا ثُمَامَةُ بْنُ عَبْدِ اللَّهِ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَانَ إِذَا تَكَلَّمَ بِكَلِمَةٍ أَعَادَهَا ثَلاَثًا حَتَّى تُفْهَمَ عَنْهُ، وَإِذَا أَتَى عَلَى قَوْمٍ فَسَلَّمَ عَلَيْهِمْ سَلَّمَ عَلَيْهِمْ ثَلاَثًا‏.‏\hadithno{95}\hadithtrans{Narrated Anas:Whenever the Prophet (ﷺ) spoke a sentence (said a thing), he used to repeat it thrice so that the people could understand it properly from him and whenever he asked permission to enter, (he knocked the door) thrice with greeting}}
\hadithdefcmd{bukhari}{96}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي بِشْرٍ، عَنْ يُوسُفَ بْنِ مَاهَكَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ تَخَلَّفَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي سَفَرٍ سَافَرْنَاهُ فَأَدْرَكَنَا وَقَدْ أَرْهَقْنَا الصَّلاَةَ صَلاَةَ الْعَصْرِ وَنَحْنُ نَتَوَضَّأُ، فَجَعَلْنَا نَمْسَحُ عَلَى أَرْجُلِنَا، فَنَادَى بِأَعْلَى صَوْتِهِ ‏ "‏ وَيْلٌ لِلأَعْقَابِ مِنَ النَّارِ ‏"‏‏.‏ مَرَّتَيْنِ أَوْ ثَلاَثًا‏.‏\hadithno{96}\hadithtrans{Narrated `Abdullah bin `Amr:Once Allah's Messenger (ﷺ) remained behind us in a journey. He joined us while we were performing ablution for the `Asr prayer which was over-due. We were just passing wet hands over our feet (not washing them properly) so the Prophet (ﷺ) addressed us in a loud voice and said twice or thrice, "Save your heels from the fire}}
\hadithdefcmd{bukhari}{97}{أَخْبَرَنَا مُحَمَّدٌ ـ هُوَ ابْنُ سَلاَمٍ ـ حَدَّثَنَا الْمُحَارِبِيُّ، قَالَ حَدَّثَنَا صَالِحُ بْنُ حَيَّانَ، قَالَ قَالَ عَامِرٌ الشَّعْبِيُّ حَدَّثَنِي أَبُو بُرْدَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ثَلاَثَةٌ لَهُمْ أَجْرَانِ رَجُلٌ مِنْ أَهْلِ الْكِتَابِ آمَنَ بِنَبِيِّهِ، وَآمَنَ بِمُحَمَّدٍ صلى الله عليه وسلم وَالْعَبْدُ الْمَمْلُوكُ إِذَا أَدَّى حَقَّ اللَّهِ وَحَقَّ مَوَالِيهِ، وَرَجُلٌ كَانَتْ عِنْدَهُ أَمَةٌ ‏\{‏يَطَؤُهَا‏\}‏ فَأَدَّبَهَا، فَأَحْسَنَ تَأْدِيبَهَا، وَعَلَّمَهَا فَأَحْسَنَ تَعْلِيمَهَا، ثُمَّ أَعْتَقَهَا فَتَزَوَّجَهَا، فَلَهُ أَجْرَانِ ‏"‏‏.‏ ثُمَّ قَالَ عَامِرٌ أَعْطَيْنَاكَهَا بِغَيْرِ شَىْءٍ، قَدْ كَانَ يُرْكَبُ فِيمَا دُونَهَا إِلَى الْمَدِينَةِ‏.‏\hadithno{97}\hadithtrans{Narrated Abu Burda's father: Allah's Messenger (ﷺ) said "Three persons will have a double reward: 1. A Person from the people of the scriptures who believed in his prophet (Jesus or Moses) and then believed in the Prophet Muhammad (ﷺ) (i.e. has embraced Islam). 2. A slave who discharges his duties to Allah and his master. 3. A master of a woman-slave who teaches her good manners and educates her in the best possible way (the religion) and manumits her and then marries her}}
\hadithdefcmd{bukhari}{98}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَيُّوبَ، قَالَ سَمِعْتُ عَطَاءً، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، قَالَ أَشْهَدُ عَلَى النَّبِيِّ صلى الله عليه وسلم ـ أَوْ قَالَ عَطَاءٌ أَشْهَدُ عَلَى ابْنِ عَبَّاسٍ ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ وَمَعَهُ بِلاَلٌ، فَظَنَّ أَنَّهُ لَمْ يُسْمِعِ النِّسَاءَ فَوَعَظَهُنَّ، وَأَمَرَهُنَّ بِالصَّدَقَةِ، فَجَعَلَتِ الْمَرْأَةُ تُلْقِي الْقُرْطَ وَالْخَاتَمَ، وَبِلاَلٌ يَأْخُذُ فِي طَرَفِ ثَوْبِهِ‏.‏ وَقَالَ إِسْمَاعِيلُ عَنْ أَيُّوبَ عَنْ عَطَاءٍ وَقَالَ عَنِ ابْنِ عَبَّاسٍ أَشْهَدُ عَلَى النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{98}\hadithtrans{Narrated Ibn 'Abbas: Once Allah's Messenger (ﷺ) came out while Bilal was accompanying him. He went towards the women thinking that they had not heard him (i.e. his sermon). So he preached them and ordered them to pay alms. (Hearing that) the women started giving alms; some donated their ear-rings, some gave their rings and Bilal was collecting them in the corner of his garment}}
\hadithdefcmd{bukhari}{99}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي سُلَيْمَانُ، عَنْ عَمْرِو بْنِ أَبِي عَمْرٍو، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ قَالَ قِيلَ يَا رَسُولَ اللَّهِ، مَنْ أَسْعَدُ النَّاسِ بِشَفَاعَتِكَ يَوْمَ الْقِيَامَةِ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَقَدْ ظَنَنْتُ يَا أَبَا هُرَيْرَةَ أَنْ لاَ يَسْأَلَنِي عَنْ هَذَا الْحَدِيثِ أَحَدٌ أَوَّلُ مِنْكَ، لِمَا رَأَيْتُ مِنْ حِرْصِكَ عَلَى الْحَدِيثِ، أَسْعَدُ النَّاسِ بِشَفَاعَتِي يَوْمَ الْقِيَامَةِ مَنْ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ، خَالِصًا مِنْ قَلْبِهِ أَوْ نَفْسِهِ ‏"‏‏.‏\hadithno{99}\hadithtrans{Narrated Abu Huraira:I said: "O Allah's Messenger (ﷺ)! Who will be the luckiest person, who will gain your intercession on the Day of Resurrection?" Allah's Messenger (ﷺ) said: "O Abu Huraira! I have thought that none will ask me about it before you as I know your longing for the (learning of) Hadiths. The luckiest person who will have my intercession on the Day of Resurrection will be the one who said sincerely from the bottom of his heart "None has the right to be worshipped but Allah}}
\hadithdefcmd{bukhari}{100}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي أُوَيْسٍ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ اللَّهَ لاَ يَقْبِضُ الْعِلْمَ انْتِزَاعًا، يَنْتَزِعُهُ مِنَ الْعِبَادِ، وَلَكِنْ يَقْبِضُ الْعِلْمَ بِقَبْضِ الْعُلَمَاءِ، حَتَّى إِذَا لَمْ يُبْقِ عَالِمًا، اتَّخَذَ النَّاسُ رُءُوسًا جُهَّالاً فَسُئِلُوا، فَأَفْتَوْا بِغَيْرِ عِلْمٍ، فَضَلُّوا وَأَضَلُّوا ‏"‏‏. قَالَ الْفِرَبْرِيُّ حَدَّثَنَا عَبَّاسٌ قَالَ حَدَّثَنَا قُتَيْبَةُ حَدَّثَنَا جَرِيرٌ عَنْ هِشَامٍ نَحْوَهُ‏.‏\hadithno{100}\hadithtrans{Narrated `Abdullah bin `Amr bin Al-`As:I heard Allah's Messenger (ﷺ) saying, "Allah does not take away the knowledge, by taking it away from (the hearts of) the people, but takes it away by the death of the religious learned men till when none of the (religious learned men) remains, people will take as their leaders ignorant persons who when consulted will give their verdict without knowledge. So they will go astray and will lead the people astray}}
\hadithdefcmd{bukhari}{101}{حَدَّثَنَا آدَمُ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثَنِي ابْنُ الأَصْبَهَانِيِّ، قَالَ سَمِعْتُ أَبَا صَالِحٍ، ذَكْوَانَ يُحَدِّثُ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ،‏.‏ قَالَتِ النِّسَاءُ لِلنَّبِيِّ صلى الله عليه وسلم غَلَبَنَا عَلَيْكَ الرِّجَالُ، فَاجْعَلْ لَنَا يَوْمًا مِنْ نَفْسِكَ‏.‏ فَوَعَدَهُنَّ يَوْمًا لَقِيَهُنَّ فِيهِ، فَوَعَظَهُنَّ وَأَمَرَهُنَّ، فَكَانَ فِيمَا قَالَ لَهُنَّ ‏"‏ مَا مِنْكُنَّ امْرَأَةٌ تُقَدِّمُ ثَلاَثَةً مِنْ وَلَدِهَا إِلاَّ كَانَ لَهَا حِجَابًا مِنَ النَّارِ ‏"‏‏.‏ فَقَالَتِ امْرَأَةٌ وَاثْنَيْنِ فَقَالَ ‏"‏ وَاثْنَيْنِ ‏"‏‏.‏\hadithno{101}\hadithtrans{Narrated Abu Sa`id Al-Khudri:Some women requested the Prophet (ﷺ) to fix a day for them as the men were taking all his time. On that he promised them one day for religious lessons and commandments. Once during such a lesson the Prophet said, "A woman whose three children die will be shielded by them from the Hell fire." On that a woman asked, "If only two die?" He replied, "Even two (will shield her from the Hell-fire)}}
\hadithdefcmd{bukhari}{102}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا غُنْدَرٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الأَصْبَهَانِيِّ، عَنْ ذَكْوَانَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا‏.‏ وَعَنْ عَبْدِ الرَّحْمَنِ بْنِ الأَصْبَهَانِيِّ، قَالَ سَمِعْتُ أَبَا حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ ‏ "‏ ثَلاَثَةً لَمْ يَبْلُغُوا الْحِنْثَ ‏"‏‏.‏\hadithno{102}\hadithtrans{Narrated Abu Sa`id Al-Khudri:as above (the sub narrators are different). Abu Huraira qualified the three children referred to in the above mentioned Hadith as not having reached the age of committing sins (i.e. age of puberty)}}
\hadithdefcmd{bukhari}{103}{حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، قَالَ أَخْبَرَنَا نَافِعُ بْنُ عُمَرَ، قَالَ حَدَّثَنِي ابْنُ أَبِي مُلَيْكَةَ، أَنَّ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم كَانَتْ لاَ تَسْمَعُ شَيْئًا لاَ تَعْرِفُهُ إِلاَّ رَاجَعَتْ فِيهِ حَتَّى تَعْرِفَهُ، وَأَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ حُوسِبَ عُذِّبَ ‏"‏‏.‏ قَالَتْ عَائِشَةُ فَقُلْتُ أَوَ لَيْسَ يَقُولُ اللَّهُ تَعَالَى ‏\{‏فَسَوْفَ يُحَاسَبُ حِسَابًا يَسِيرًا‏\}‏ قَالَتْ فَقَالَ ‏"‏ إِنَّمَا ذَلِكَ الْعَرْضُ، وَلَكِنْ مَنْ نُوقِشَ الْحِسَابَ يَهْلِكْ ‏"‏‏.‏\hadithno{103}\hadithtrans{Narrated Ibn Abu Mulaika:Whenever `Aisha (the wife of the Prophet) heard anything which she did not understand, she used to ask again till she understood it completely. Aisha said: "Once the Prophet (ﷺ) said, "Whoever will be called to account (about his deeds on the Day of Resurrection) will surely be punished." I said, "Doesn't Allah say: "He surely will receive an easy reckoning." (84.8) The Prophet (ﷺ) replied, "This means only the presentation of the accounts but whoever will be argued about his account, will certainly be ruined}}
\hadithdefcmd{bukhari}{104}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ حَدَّثَنِي اللَّيْثُ، قَالَ حَدَّثَنِي سَعِيدٌ، عَنْ أَبِي شُرَيْحٍ، أَنَّهُ قَالَ لِعَمْرِو بْنِ سَعِيدٍ وَهْوَ يَبْعَثُ الْبُعُوثَ إِلَى مَكَّةَ ائْذَنْ لِي أَيُّهَا الأَمِيرُ أُحَدِّثْكَ قَوْلاً قَامَ بِهِ النَّبِيُّ صلى الله عليه وسلم الْغَدَ مِنْ يَوْمِ الْفَتْحِ، سَمِعَتْهُ أُذُنَاىَ وَوَعَاهُ قَلْبِي، وَأَبْصَرَتْهُ عَيْنَاىَ، حِينَ تَكَلَّمَ بِهِ، حَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ ثُمَّ قَالَ ‏ "‏ إِنَّ مَكَّةَ حَرَّمَهَا اللَّهُ، وَلَمْ يُحَرِّمْهَا النَّاسُ، فَلاَ يَحِلُّ لاِمْرِئٍ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ أَنْ يَسْفِكَ بِهَا دَمًا، وَلاَ يَعْضِدَ بِهَا شَجَرَةً، فَإِنْ أَحَدٌ تَرَخَّصَ لِقِتَالِ رَسُولِ اللَّهِ صلى الله عليه وسلم فِيهَا فَقُولُوا إِنَّ اللَّهَ قَدْ أَذِنَ لِرَسُولِهِ، وَلَمْ يَأْذَنْ لَكُمْ‏.‏ وَإِنَّمَا أَذِنَ لِي فِيهَا سَاعَةً مِنْ نَهَارٍ، ثُمَّ عَادَتْ حُرْمَتُهَا الْيَوْمَ كَحُرْمَتِهَا بِالأَمْسِ، وَلْيُبَلِّغِ الشَّاهِدُ الْغَائِبَ ‏"‏‏.‏ فَقِيلَ لأَبِي شُرَيْحٍ مَا قَالَ عَمْرٌو قَالَ أَنَا أَعْلَمُ مِنْكَ يَا أَبَا شُرَيْحٍ، لاَ يُعِيذُ عَاصِيًا، وَلاَ فَارًّا بِدَمٍ، وَلاَ فَارًّا بِخَرْبَةٍ‏.‏\hadithno{104}\hadithtrans{Narrated Sa`id:Abu Shuraih said, "When `Amr bin Sa`id was sending the troops to Mecca (to fight `Abdullah bin Az-Zubair) I said to him, 'O chief! Allow me to tell you what the Prophet (ﷺ) said on the day following the conquests of Mecca. My ears heard and my heart comprehended, and I saw him with my own eyes, when he said it. He glorified and praised Allah and then said, "Allah and not the people has made Mecca a sanctuary. So anybody who has belief in Allah and the Last Day (i.e. a Muslim) should neither shed blood in it nor cut down its trees. If anybody argues that fighting is allowed in Mecca as Allah's Messenger (ﷺ) did fight (in Mecca), tell him that Allah gave permission to His Apostle, but He did not give it to you. The Prophet (ﷺ) added: Allah allowed me only for a few hours on that day (of the conquest) and today (now) its sanctity is the same (valid) as it was before. So it is incumbent upon those who are present to convey it (this information) to those who are absent." Abu- Shuraih was asked, "What did `Amr reply?" He said `Amr said, "O Abu Shuraih! I know better than you (in this respect). Mecca does not give protection to one who disobeys (Allah) or runs after committing murder, or theft (and takes refuge in Mecca)}}
\hadithdefcmd{bukhari}{105}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الْوَهَّابِ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، عَنِ ابْنِ أَبِي بَكْرَةَ، عَنْ أَبِي بَكْرَةَ، ذُكِرَ النَّبِيُّ صلى الله عليه وسلم قَالَ ‏"‏ فَإِنَّ دِمَاءَكُمْ وَأَمْوَالَكُمْ ـ قَالَ مُحَمَّدٌ وَأَحْسِبُهُ قَالَ وَأَعْرَاضَكُمْ ـ عَلَيْكُمْ حَرَامٌ كَحُرْمَةِ يَوْمِكُمْ هَذَا فِي شَهْرِكُمْ هَذَا، أَلاَ لِيُبَلِّغِ الشَّاهِدُ مِنْكُمُ الْغَائِبَ ‏"‏‏.‏ وَكَانَ مُحَمَّدٌ يَقُولُ صَدَقَ رَسُولُ اللَّهِ صلى الله عليه وسلم كَانَ ذَلِكَ ‏"‏ أَلاَ هَلْ بَلَّغْتُ ‏"‏ مَرَّتَيْنِ‏.‏\hadithno{105}\hadithtrans{Narrated Abu Bakra:The Prophet (ﷺ) said, "No doubt your blood, property, the sub-narrator Muhammad thought that Abu Bakra had also mentioned and your honor (chastity), are sacred to one another as is the sanctity of this day of yours in this month of yours. It is incumbent on those who are present to inform those who are absent." (Muhammad the Sub-narrator used to say, "Allah's Messenger (ﷺ) told the truth.") The Prophet (ﷺ) repeated twice: "No doubt! Haven't I conveyed Allah's message to you}}
\hadithdefcmd{bukhari}{106}{حَدَّثَنَا عَلِيُّ بْنُ الْجَعْدِ، قَالَ أَخْبَرَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي مَنْصُورٌ، قَالَ سَمِعْتُ رِبْعِيَّ بْنَ حِرَاشٍ، يَقُولُ سَمِعْتُ عَلِيًّا، يَقُولُ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ تَكْذِبُوا عَلَىَّ، فَإِنَّهُ مَنْ كَذَبَ عَلَىَّ فَلْيَلِجِ النَّارَ ‏"‏‏.‏\hadithno{106}\hadithtrans{Narrated `Ali:The Prophet (ﷺ) said, "Do not tell a lie against me for whoever tells a lie against me (intentionally) then he will surely enter the Hell-fire}}
\hadithdefcmd{bukhari}{107}{حَدَّثَنَا أَبُو الْوَلِيدِ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ جَامِعِ بْنِ شَدَّادٍ، عَنْ عَامِرِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ أَبِيهِ، قَالَ قُلْتُ لِلزُّبَيْرِ إِنِّي لاَ أَسْمَعُكَ تُحَدِّثُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم كَمَا يُحَدِّثُ فُلاَنٌ وَفُلاَنٌ‏.‏ قَالَ أَمَا إِنِّي لَمْ أُفَارِقْهُ وَلَكِنْ سَمِعْتُهُ يَقُولُ ‏ "‏ مَنْ كَذَبَ عَلَىَّ فَلْيَتَبَوَّأْ مَقْعَدَهُ مِنَ النَّارِ ‏"‏‏.‏\hadithno{107}\hadithtrans{Narrated `Abdullah bin Az-Zubair:I said to my father, 'I do not hear from you any narration (Hadith) of Allah's Apostle as I hear (his narration) from so and so?" Az-Zubair replied, 'I was always with him (the Prophet) and I heard him saying, "Whoever tells a lie against me (intentionally) then (surely) let him occupy, his seat in Hellfire}}
\hadithdefcmd{bukhari}{108}{حَدَّثَنَا أَبُو مَعْمَرٍ، قَالَ حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ عَبْدِ الْعَزِيزِ، قَالَ أَنَسٌ إِنَّهُ لَيَمْنَعُنِي أَنْ أُحَدِّثَكُمْ حَدِيثًا كَثِيرًا أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ تَعَمَّدَ عَلَىَّ كَذِبًا فَلْيَتَبَوَّأْ مَقْعَدَهُ مِنَ النَّارِ ‏"‏‏.‏\hadithno{108}\hadithtrans{Narrated Anas:The fact which stops me from narrating a great number of Hadiths to you is that the Prophet (ﷺ) said: "Whoever tells a lie against me intentionally, then (surely) let him occupy his seat in Hell-fire}}
\hadithdefcmd{bukhari}{109}{حَدَّثَنَا مَكِّيُّ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ أَبِي عُبَيْدٍ، عَنْ سَلَمَةَ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ يَقُلْ عَلَىَّ مَا لَمْ أَقُلْ فَلْيَتَبَوَّأْ مَقْعَدَهُ مِنَ النَّارِ ‏"‏‏.‏\hadithno{109}\hadithtrans{Narrated Salama:I heard the Prophet (ﷺ) saying, "Whoever (intentionally) ascribes to me what I have not said then (surely) let him occupy his seat in Hell-fire}}
\hadithdefcmd{bukhari}{110}{حَدَّثَنَا مُوسَى، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي حَصِينٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ تَسَمَّوْا بِاسْمِي وَلاَ تَكْتَنُوا بِكُنْيَتِي، وَمَنْ رَآنِي فِي الْمَنَامِ فَقَدْ رَآنِي، فَإِنَّ الشَّيْطَانَ لاَ يَتَمَثَّلُ فِي صُورَتِي، وَمَنْ كَذَبَ عَلَىَّ مُتَعَمِّدًا فَلْيَتَبَوَّأْ مَقْعَدَهُ مِنَ النَّارِ ‏"‏‏.‏\hadithno{110}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Name yourselves with my name (use my name) but do not name yourselves with my Kunya name (i.e. Abul Qasim). And whoever sees me in a dream then surely he has seen me for Satan cannot impersonate me. And whoever tells a lie against me (intentionally), then (surely) let him occupy his seat in Hell-fire}}
\hadithdefcmd{bukhari}{111}{حَدَّثَنَا مُحَمَّدُ بْنُ سَلاَمٍ، قَالَ أَخْبَرَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ مُطَرِّفٍ، عَنِ الشَّعْبِيِّ، عَنْ أَبِي جُحَيْفَةَ، قَالَ قُلْتُ لِعَلِيٍّ هَلْ عِنْدَكُمْ كِتَابٌ قَالَ لاَ، إِلاَّ كِتَابُ اللَّهِ، أَوْ فَهْمٌ أُعْطِيَهُ رَجُلٌ مُسْلِمٌ، أَوْ مَا فِي هَذِهِ الصَّحِيفَةِ‏.‏ قَالَ قُلْتُ فَمَا فِي هَذِهِ الصَّحِيفَةِ قَالَ الْعَقْلُ، وَفَكَاكُ الأَسِيرِ، وَلاَ يُقْتَلُ مُسْلِمٌ بِكَافِرٍ‏.‏\hadithno{111}\hadithtrans{Narrated Ash-Shu`bi:Abu Juhaifa said, "I asked `Ali, 'Have you got any book (which has been revealed to the Prophet (ﷺ) apart from the Qur'an)?' `Ali replied, 'No, except Allah's Book or the power of understanding which has been bestowed (by Allah) upon a Muslim or what is (written) in this sheet of paper (with me).' Abu Juhaifa said, "I asked, 'What is (written) in this sheet of paper?' `Ali replied, it deals with The Diyya (compensation (blood money) paid by the killer to the relatives of the victim), the ransom for the releasing of the captives from the hands of the enemies, and the law that no Muslim should be killed in Qisas (equality in punishment) for the killing of (a disbeliever)}}
\hadithdefcmd{bukhari}{112}{حَدَّثَنَا أَبُو نُعَيْمٍ الْفَضْلُ بْنُ دُكَيْنٍ، قَالَ حَدَّثَنَا شَيْبَانُ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ خُزَاعَةَ، قَتَلُوا رَجُلاً مِنْ بَنِي لَيْثٍ عَامَ فَتْحِ مَكَّةَ بِقَتِيلٍ مِنْهُمْ قَتَلُوهُ، فَأُخْبِرَ بِذَلِكَ النَّبِيُّ صلى الله عليه وسلم فَرَكِبَ رَاحِلَتَهُ، فَخَطَبَ فَقَالَ ‏"‏ إِنَّ اللَّهَ حَبَسَ عَنْ مَكَّةَ الْقَتْلَ ـ أَوِ الْفِيلَ شَكَّ أَبُو عَبْدِ اللَّهِ ـ وَسَلَّطَ عَلَيْهِمْ رَسُولَ اللَّهِ صلى الله عليه وسلم وَالْمُؤْمِنِينَ، أَلاَ وَإِنَّهَا لَمْ تَحِلَّ لأَحَدٍ قَبْلِي، وَلاَ تَحِلُّ لأَحَدٍ بَعْدِي أَلاَ وَإِنَّهَا حَلَّتْ لِي سَاعَةً مِنْ نَهَارٍ، أَلاَ وَإِنَّهَا سَاعَتِي هَذِهِ حَرَامٌ، لاَ يُخْتَلَى شَوْكُهَا، وَلاَ يُعْضَدُ شَجَرُهَا، وَلاَ تُلْتَقَطُ سَاقِطَتُهَا إِلاَّ لِمُنْشِدٍ، فَمَنْ قُتِلَ فَهُوَ بِخَيْرِ النَّظَرَيْنِ إِمَّا أَنْ يُعْقَلَ، وَإِمَّا أَنْ يُقَادَ أَهْلُ الْقَتِيلِ ‏"‏‏.‏ فَجَاءَ رَجُلٌ مِنْ أَهْلِ الْيَمَنِ فَقَالَ اكْتُبْ لِي يَا رَسُولَ اللَّهِ‏.‏ فَقَالَ ‏"‏ اكْتُبُوا لأَبِي فُلاَنٍ ‏"‏‏.‏ فَقَالَ رَجُلٌ مِنْ قُرَيْشٍ إِلاَّ الإِذْخِرَ يَا رَسُولَ اللَّهِ، فَإِنَّا نَجْعَلُهُ فِي بُيُوتِنَا وَقُبُورِنَا‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِلاَّ الإِذْخِرَ، إِلاَّ الإِذْخِرَ ‏"‏‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ يُقَالُ يُقَادُ بِالْقَافِ‏.‏ فَقِيلَ لأَبِي عَبْدِ اللَّهِ أَىُّ شَىْءٍ كَتَبَ لَهُ قَالَ كَتَبَ لَهُ هَذِهِ الْخُطْبَةَ‏.‏\hadithno{112}\hadithtrans{Narrated Abu Huraira:In the year of the Conquest of Mecca, the tribe of Khuza`a killed a man from the tribe of Bani Laith in revenge for a killed person, belonging to them. They informed the Prophet (ﷺ) about it. So he rode his Rahila (she-camel for riding) and addressed the people saying, "Allah held back the killing from Mecca. (The sub-narrator is in doubt whether the Prophet (ﷺ) said "elephant or killing," as the Arabic words standing for these words have great similarity in shape), but He (Allah) let His Apostle and the believers over power the infidels of Mecca. Beware! (Mecca is a sanctuary) Verily! Fighting in Mecca was not permitted for anyone before me nor will it be permitted for anyone after me. It (war) in it was made legal for me for few hours or so on that day. No doubt it is at this moment a sanctuary, it is not allowed to uproot its thorny shrubs or to uproot its trees or to pick up its Luqat (fallen things) except by a person who will look for its owner (announce it publicly). And if somebody is killed, then his closest relative has the right to choose one of the two-- the blood money (Diyya) or retaliation having the killer killed. In the meantime a man from Yemen came and said, "O Allah's Messenger (ﷺ)! Get that written for me." The Prophet (ﷺ) ordered his companions to write that for him. Then a man from Quraish said, "Except Al-Idhkhir (a type of grass that has good smell) O Allah's Messenger (ﷺ), as we use it in our houses and graves." The Prophet (ﷺ) said, "Except Al-Idhkhir i.e. Al-Idhkhir is allowed to be plucked}}
\hadithdefcmd{bukhari}{113}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنَا عَمْرٌو، قَالَ أَخْبَرَنِي وَهْبُ بْنُ مُنَبِّهٍ، عَنْ أَخِيهِ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ مَا مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم أَحَدٌ أَكْثَرَ حَدِيثًا عَنْهُ مِنِّي، إِلاَّ مَا كَانَ مِنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو فَإِنَّهُ كَانَ يَكْتُبُ وَلاَ أَكْتُبُ‏.‏ تَابَعَهُ مَعْمَرٌ عَنْ هَمَّامٍ عَنْ أَبِي هُرَيْرَةَ‏.‏\hadithno{113}\hadithtrans{Narrated Abu Huraira:There is none among the companions of the Prophet (ﷺ) who has narrated more Hadiths than I except `Abdullah bin `Amr (bin Al-`As) who used to write them and I never did the same}}
\hadithdefcmd{bukhari}{114}{حَدَّثَنَا يَحْيَى بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنِي ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ لَمَّا اشْتَدَّ بِالنَّبِيِّ صلى الله عليه وسلم وَجَعُهُ قَالَ ‏"‏ ائْتُونِي بِكِتَابٍ أَكْتُبُ لَكُمْ كِتَابًا لاَ تَضِلُّوا بَعْدَهُ ‏"‏‏.‏ قَالَ عُمَرُ إِنَّ النَّبِيَّ صلى الله عليه وسلم غَلَبَهُ الْوَجَعُ وَعِنْدَنَا كِتَابُ اللَّهِ حَسْبُنَا فَاخْتَلَفُوا وَكَثُرَ اللَّغَطُ‏.‏ قَالَ ‏"‏ قُومُوا عَنِّي، وَلاَ يَنْبَغِي عِنْدِي التَّنَازُعُ ‏"‏‏.‏ فَخَرَجَ ابْنُ عَبَّاسٍ يَقُولُ إِنَّ الرَّزِيَّةَ كُلَّ الرَّزِيَّةِ مَا حَالَ بَيْنَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَبَيْنَ كِتَابِهِ‏.‏\hadithno{114}\hadithtrans{Narrated 'Ubaidullah bin `Abdullah:Ibn `Abbas said, "When the ailment of the Prophet (ﷺ) became worse, he said, 'Bring for me (writing) paper and I will write for you a statement after which you will not go astray.' But `Umar said, 'The Prophet is seriously ill, and we have got Allah's Book with us and that is sufficient for us.' But the companions of the Prophet (ﷺ) differed about this and there was a hue and cry. On that the Prophet (ﷺ) said to them, 'Go away (and leave me alone). It is not right that you should quarrel in front of me." Ibn `Abbas came out saying, "It was most unfortunate (a great disaster) that Allah's Messenger (ﷺ) was prevented from writing that statement for them because of their disagreement and noise. (Note: It is apparent from this Hadith that Ibn `Abbas had witnessed the event and came out saying this statement. The truth is not so, for Ibn `Abbas used to say this statement on narrating the Hadith and he had not witnessed the event personally. See Fath Al-Bari Vol. 1, p.220 footnote.) (See Hadith No. 228, Vol)}}
\hadithdefcmd{bukhari}{115}{حَدَّثَنَا صَدَقَةُ، أَخْبَرَنَا ابْنُ عُيَيْنَةَ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ هِنْدٍ، عَنْ أُمِّ سَلَمَةَ، وَعَمْرٍو، وَيَحْيَى بْنِ سَعِيدٍ، عَنِ الزُّهْرِيِّ، عَنْ هِنْدٍ، عَنْ أُمِّ سَلَمَةَ، قَالَتِ اسْتَيْقَظَ النَّبِيُّ صلى الله عليه وسلم ذَاتَ لَيْلَةٍ فَقَالَ ‏ "‏ سُبْحَانَ اللَّهِ مَاذَا أُنْزِلَ اللَّيْلَةَ مِنَ الْفِتَنِ وَمَاذَا فُتِحَ مِنَ الْخَزَائِنِ أَيْقِظُوا صَوَاحِبَاتِ الْحُجَرِ، فَرُبَّ كَاسِيَةٍ فِي الدُّنْيَا عَارِيَةٍ فِي الآخِرَةِ ‏"‏‏.‏\hadithno{115}\hadithtrans{Narrated Um Salama:One night Allah's Messenger (ﷺ) got up and said, "Subhan Allah! How many afflictions have been descended tonight and how many treasures have been disclosed! Go and wake the sleeping lady occupants of these dwellings (his wives) up (for prayers). A well-dressed (soul) in this world may be naked in the Hereafter}}
\hadithdefcmd{bukhari}{116}{حَدَّثَنَا سَعِيدُ بْنُ عُفَيْرٍ، قَالَ حَدَّثَنِي اللَّيْثُ، قَالَ حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ خَالِدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمٍ، وَأَبِي، بَكْرِ بْنِ سُلَيْمَانَ بْنِ أَبِي حَثْمَةَ أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، قَالَ صَلَّى بِنَا النَّبِيُّ صلى الله عليه وسلم الْعِشَاءَ فِي آخِرِ حَيَاتِهِ، فَلَمَّا سَلَّمَ قَامَ فَقَالَ ‏ "‏ أَرَأَيْتَكُمْ لَيْلَتَكُمْ هَذِهِ، فَإِنَّ رَأْسَ مِائَةِ سَنَةٍ مِنْهَا لاَ يَبْقَى مِمَّنْ هُوَ عَلَى ظَهْرِ الأَرْضِ أَحَدٌ ‏"‏‏.‏\hadithno{116}\hadithtrans{Narrated `Abdullah bin `Umar:Once the Prophet (ﷺ) led us in the `Isha' prayer during the last days of his life and after finishing it (the prayer) (with Taslim) he said: "Do you realize (the importance of) this night?" Nobody present on the surface of the earth tonight will be living after the completion of one hundred years from this night}}
\hadithdefcmd{bukhari}{117}{حَدَّثَنَا آدَمُ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثَنَا الْحَكَمُ، قَالَ سَمِعْتُ سَعِيدَ بْنَ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ بِتُّ فِي بَيْتِ خَالَتِي مَيْمُونَةَ بِنْتِ الْحَارِثِ زَوْجِ النَّبِيِّ صلى الله عليه وسلم وَكَانَ النَّبِيُّ صلى الله عليه وسلم عِنْدَهَا فِي لَيْلَتِهَا، فَصَلَّى النَّبِيُّ صلى الله عليه وسلم الْعِشَاءَ، ثُمَّ جَاءَ إِلَى مَنْزِلِهِ، فَصَلَّى أَرْبَعَ رَكَعَاتٍ، ثُمَّ نَامَ، ثُمَّ قَامَ، ثُمَّ قَالَ ‏ "‏ نَامَ الْغُلَيِّمُ ‏"‏‏.‏ أَوْ كَلِمَةً تُشْبِهُهَا، ثُمَّ قَامَ فَقُمْتُ عَنْ يَسَارِهِ، فَجَعَلَنِي عَنْ يَمِينِهِ، فَصَلَّى خَمْسَ رَكَعَاتٍ ثُمَّ صَلَّى رَكْعَتَيْنِ، ثُمَّ نَامَ حَتَّى سَمِعْتُ غَطِيطَهُ ـ أَوْ خَطِيطَهُ ـ ثُمَّ خَرَجَ إِلَى الصَّلاَةِ‏.‏\hadithno{117}\hadithtrans{Narrated Ibn `Abbas:I stayed overnight in the house of my aunt Maimuna bint Al-Harith (the wife of the Prophet (ﷺ) ) while the Prophet (ﷺ) was there with her during her night turn. The Prophet (ﷺ) offered the `Isha' prayer (in the mosque), returned home and after having prayed four rak`at, he slept. Later on he got up at night and then asked whether the boy (or he used a similar word) had slept? Then he got up for the prayer and I stood up by his left side but he made me stand to his right and offered five rak`at followed by two more rak`at. Then he slept and I heard him snoring and then (after a while) he left for the (Fajr) prayer}}
\hadithdefcmd{bukhari}{118}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ إِنَّ النَّاسَ يَقُولُونَ أَكْثَرَ أَبُو هُرَيْرَةَ، وَلَوْلاَ آيَتَانِ فِي كِتَابِ اللَّهِ مَا حَدَّثْتُ حَدِيثًا، ثُمَّ يَتْلُو ‏\{‏إِنَّ الَّذِينَ يَكْتُمُونَ مَا أَنْزَلْنَا مِنَ الْبَيِّنَاتِ‏\}‏ إِلَى قَوْلِهِ ‏\{‏الرَّحِيمُ‏\}‏ إِنَّ إِخْوَانَنَا مِنَ الْمُهَاجِرِينَ كَانَ يَشْغَلُهُمُ الصَّفْقُ بِالأَسْوَاقِ، وِإِنَّ إِخْوَانَنَا مِنَ الأَنْصَارِ كَانَ يَشْغَلُهُمُ الْعَمَلُ فِي أَمْوَالِهِمْ، وَإِنَّ أَبَا هُرَيْرَةَ كَانَ يَلْزَمُ رَسُولَ اللَّهِ صلى الله عليه وسلم بِشِبَعِ بَطْنِهِ وَيَحْضُرُ مَا لاَ يَحْضُرُونَ، وَيَحْفَظُ مَا لاَ يَحْفَظُونَ‏.‏\hadithno{118}\hadithtrans{Narrated Abu Huraira:People say that I have narrated many Hadiths (The Prophet's narration). Had it not been for two verses in the Qur'an, I would not have narrated a single Hadith, and the verses are: "Verily those who conceal the clear sign and the guidance which We have sent down . . . (up to) Most Merciful." (2:159-160). And no doubt our Muhajir (emigrant) brothers used to be busy in the market with their business (bargains) and our Ansari brothers used to be busy with their property (agriculture). But I (Abu Huraira) used to stick to Allah's Messenger (ﷺ) contented with what will fill my stomach and I used to attend that which they used not to attend and I used to memorize that which they used not to memorize}}
\hadithdefcmd{bukhari}{119}{حَدَّثَنَا أَحْمَدُ بْنُ أَبِي بَكْرٍ أَبُو مُصْعَبٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ إِبْرَاهِيمَ بْنِ دِينَارٍ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ، إِنِّي أَسْمَعُ مِنْكَ حَدِيثًا كَثِيرًا أَنْسَاهُ‏.‏ قَالَ ‏"‏ ابْسُطْ رِدَاءَكَ ‏"‏ فَبَسَطْتُهُ‏.‏ قَالَ فَغَرَفَ بِيَدَيْهِ ثُمَّ قَالَ ‏"‏ ضُمُّهُ ‏"‏ فَضَمَمْتُهُ فَمَا نَسِيتُ شَيْئًا بَعْدَهُ‏. حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ قَالَ حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ بِهَذَا أَوْ قَالَ غَرَفَ بِيَدِهِ فِيهِ‏.‏\hadithno{119}\hadithtrans{Narrated Abu Huraira:I said to Allah's Messenger (ﷺ) "I hear many narrations (Hadiths) from you but I forget them." Allah's Apostle said, "Spread your Rida' (garment)." I did accordingly and then he moved his hands as if filling them with something (and emptied them in my Rida') and then said, "Take and wrap this sheet over your body." I did it and after that I never forgot any thing. Narrated Ibrahim bin Al-Mundhir: Ibn Abi Fudaik narrated the same as above (Hadith...119) but added that the Prophet (ﷺ) had moved his hands as if filling them with something and then he emptied them in the Rida' of Abu Huraira}}
\hadithdefcmd{bukhari}{120}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي أَخِي، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ حَفِظْتُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وِعَاءَيْنِ، فَأَمَّا أَحَدُهُمَا فَبَثَثْتُهُ، وَأَمَّا الآخَرُ فَلَوْ بَثَثْتُهُ قُطِعَ هَذَا الْبُلْعُومُ‏.‏\hadithno{120}\hadithtrans{Narrated Abu Huraira:I have memorized two kinds of knowledge from Allah's Messenger (ﷺ) . I have propagated one of them to you and if I propagated the second, then my pharynx (throat) would be cut (i.e. killed)}}
\hadithdefcmd{bukhari}{121}{حَدَّثَنَا حَجَّاجٌ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي عَلِيُّ بْنُ مُدْرِكٍ، عَنْ أَبِي زُرْعَةَ، عَنْ جَرِيرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لَهُ فِي حَجَّةِ الْوَدَاعِ ‏"‏ اسْتَنْصِتِ النَّاسَ ‏"‏ فَقَالَ ‏"‏ لاَ تَرْجِعُوا بَعْدِي كُفَّارًا يَضْرِبُ بَعْضُكُمْ رِقَابَ بَعْضٍ ‏"‏‏.‏\hadithno{121}\hadithtrans{Narrated Jarir:The Prophet (ﷺ) said to me during Hajjat-al-Wida`: Let the people keep quiet and listen. Then he said (addressing the people), "Do not (become infidels) revert to disbelief after me by striking the necks (cutting the throats) of one another (killing each other)}}
\hadithdefcmd{bukhari}{122}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنَا عَمْرٌو، قَالَ أَخْبَرَنِي سَعِيدُ بْنُ جُبَيْرٍ، قَالَ قُلْتُ لاِبْنِ عَبَّاسٍ إِنَّ نَوْفًا الْبِكَالِيَّ يَزْعُمُ أَنَّ مُوسَى لَيْسَ بِمُوسَى بَنِي إِسْرَائِيلَ، إِنَّمَا هُوَ مُوسَى آخَرُ‏.‏ فَقَالَ كَذَبَ عَدُوُّ اللَّهِ، حَدَّثَنَا أُبَىُّ بْنُ كَعْبٍ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ قَامَ مُوسَى النَّبِيُّ خَطِيبًا فِي بَنِي إِسْرَائِيلَ، فَسُئِلَ أَىُّ النَّاسِ أَعْلَمُ فَقَالَ أَنَا أَعْلَمُ‏.‏ فَعَتَبَ اللَّهُ عَلَيْهِ، إِذْ لَمْ يَرُدَّ الْعِلْمَ إِلَيْهِ، فَأَوْحَى اللَّهُ إِلَيْهِ أَنَّ عَبْدًا مِنْ عِبَادِي بِمَجْمَعِ الْبَحْرَيْنِ هُوَ أَعْلَمُ مِنْكَ‏.‏ قَالَ يَا رَبِّ وَكَيْفَ بِهِ فَقِيلَ لَهُ احْمِلْ حُوتًا فِي مِكْتَلٍ فَإِذَا فَقَدْتَهُ فَهْوَ ثَمَّ، فَانْطَلَقَ وَانْطَلَقَ بِفَتَاهُ يُوشَعَ بْنِ نُونٍ، وَحَمَلاَ حُوتًا فِي مِكْتَلٍ، حَتَّى كَانَا عِنْدَ الصَّخْرَةِ وَضَعَا رُءُوسَهُمَا وَنَامَا فَانْسَلَّ الْحُوتُ مِنَ الْمِكْتَلِ فَاتَّخَذَ سَبِيلَهُ فِي الْبَحْرِ سَرَبًا، وَكَانَ لِمُوسَى وَفَتَاهُ عَجَبًا، فَانْطَلَقَا بَقِيَّةَ لَيْلَتِهِمَا وَيَوْمِهِمَا فَلَمَّا أَصْبَحَ قَالَ مُوسَى لِفَتَاهُ آتِنَا غَدَاءَنَا، لَقَدْ لَقِينَا مِنْ سَفَرِنَا هَذَا نَصَبًا، وَلَمْ يَجِدْ مُوسَى مَسًّا مِنَ النَّصَبِ حَتَّى جَاوَزَ الْمَكَانَ الَّذِي أُمِرَ بِهِ‏.‏ فَقَالَ لَهُ فَتَاهُ أَرَأَيْتَ إِذْ أَوَيْنَا إِلَى الصَّخْرَةِ فَإِنِّي نَسِيتُ الْحُوتَ، قَالَ مُوسَى ذَلِكَ مَا كُنَّا نَبْغِي، فَارْتَدَّا عَلَى آثَارِهِمَا قَصَصًا، فَلَمَّا انْتَهَيَا إِلَى الصَّخْرَةِ إِذَا رَجُلٌ مُسَجًّى بِثَوْبٍ ـ أَوْ قَالَ تَسَجَّى بِثَوْبِهِ ـ فَسَلَّمَ مُوسَى‏.‏ فَقَالَ الْخَضِرُ وَأَنَّى بِأَرْضِكَ السَّلاَمُ فَقَالَ أَنَا مُوسَى‏.‏ فَقَالَ مُوسَى بَنِي إِسْرَائِيلَ قَالَ نَعَمْ‏.‏ قَالَ هَلْ أَتَّبِعُكَ عَلَى أَنْ تُعَلِّمَنِي مِمَّا عُلِّمْتَ رَشَدًا قَالَ إِنَّكَ لَنْ تَسْتَطِيعَ مَعِيَ صَبْرًا، يَا مُوسَى إِنِّي عَلَى عِلْمٍ مِنْ عِلْمِ اللَّهِ عَلَّمَنِيهِ لاَ تَعْلَمُهُ أَنْتَ، وَأَنْتَ عَلَى عِلْمٍ عَلَّمَكَهُ لاَ أَعْلَمُهُ‏.‏ قَالَ سَتَجِدُنِي إِنْ شَاءَ اللَّهُ صَابِرًا، وَلاَ أَعْصِي لَكَ أَمْرًا، فَانْطَلَقَا يَمْشِيَانِ عَلَى سَاحِلِ الْبَحْرِ لَيْسَ لَهُمَا سَفِينَةٌ، فَمَرَّتْ بِهِمَا سَفِينَةٌ، فَكَلَّمُوهُمْ أَنْ يَحْمِلُوهُمَا، فَعُرِفَ الْخَضِرُ، فَحَمَلُوهُمَا بِغَيْرِ نَوْلٍ، فَجَاءَ عُصْفُورٌ فَوَقَعَ عَلَى حَرْفِ السَّفِينَةِ، فَنَقَرَ نَقْرَةً أَوْ نَقْرَتَيْنِ فِي الْبَحْرِ‏.‏ فَقَالَ الْخَضِرُ يَا مُوسَى، مَا نَقَصَ عِلْمِي وَعِلْمُكَ مِنْ عِلْمِ اللَّهِ إِلاَّ كَنَقْرَةِ هَذَا الْعُصْفُورِ فِي الْبَحْرِ‏.‏ فَعَمَدَ الْخَضِرُ إِلَى لَوْحٍ مِنْ أَلْوَاحِ السَّفِينَةِ فَنَزَعَهُ‏.‏ فَقَالَ مُوسَى قَوْمٌ حَمَلُونَا بِغَيْرِ نَوْلٍ، عَمَدْتَ إِلَى سَفِينَتِهِمْ فَخَرَقْتَهَا لِتُغْرِقَ أَهْلَهَا قَالَ أَلَمْ أَقُلْ إِنَّكَ لَنْ تَسْتَطِيعَ مَعِيَ صَبْرًا قَالَ لاَ تُؤَاخِذْنِي بِمَا نَسِيتُ‏.‏ فَكَانَتِ الأُولَى مِنْ مُوسَى نِسْيَانًا‏.‏ فَانْطَلَقَا فَإِذَا غُلاَمٌ يَلْعَبُ مَعَ الْغِلْمَانِ، فَأَخَذَ الْخَضِرُ بِرَأْسِهِ مِنْ أَعْلاَهُ فَاقْتَلَعَ رَأْسَهُ بِيَدِهِ‏.‏ فَقَالَ مُوسَى أَقَتَلْتَ نَفْسًا زَكِيَّةً بِغَيْرِ نَفْسٍ قَالَ أَلَمْ أَقُلْ لَكَ إِنَّكَ لَنْ تَسْتَطِيعَ مَعِيَ صَبْرًا ـ قَالَ ابْنُ عُيَيْنَةَ وَهَذَا أَوْكَدُ ـ فَانْطَلَقَا حَتَّى إِذَا أَتَيَا أَهْلَ قَرْيَةٍ اسْتَطْعَمَا أَهْلَهَا، فَأَبَوْا أَنْ يُضَيِّفُوهُمَا، فَوَجَدَا فِيهَا جِدَارًا يُرِيدُ أَنْ يَنْقَضَّ فَأَقَامَهُ‏.‏ قَالَ الْخَضِرُ بِيَدِهِ فَأَقَامَهُ‏.‏ فَقَالَ لَهُ مُوسَى لَوْ شِئْتَ لاَتَّخَذْتَ عَلَيْهِ أَجْرًا‏.‏ قَالَ هَذَا فِرَاقُ بَيْنِي وَبَيْنِكَ ‏"‏‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ يَرْحَمُ اللَّهُ مُوسَى، لَوَدِدْنَا لَوْ صَبَرَ حَتَّى يُقَصَّ عَلَيْنَا مِنْ أَمْرِهِمَا ‏"‏‏.‏\hadithno{122}\hadithtrans{Narrated Sa`id bin Jubair:I said to Ibn `Abbas, "Nauf-Al-Bakali claims that Moses (the companion of Khadir) was not the Moses of Bani Israel but he was another Moses." Ibn `Abbas remarked that the enemy of Allah (Nauf) was a liar. Narrated Ubai bin Ka`b: The Prophet (ﷺ) said, "Once the Prophet Moses (ﷺ) stood up and addressed Bani Israel. He was asked, "Who is the most learned man amongst the people. He said, "I am the most learned." Allah admonished Moses as he did not attribute absolute knowledge to Him (Allah). So Allah inspired to him "At the junction of the two seas there is a slave amongst my slaves who is more learned than you." Moses said, "O my Lord! How can I meet him?" Allah said: Take a fish in a large basket (and proceed) and you will find him at the place where you will lose the fish. So Moses set out along with his (servant) boy, Yusha` bin Noon and carried a fish in a large basket till they reached a rock, where they laid their heads (i.e. lay down) and slept. The fish came out of the basket and it took its way into the sea as in a tunnel. So it was an amazing thing for both Moses and his (servant) boy. They proceeded for the rest of that night and the following day. When the day broke, Moses said to his (servant) boy: "Bring us our early meal. No doubt, we have suffered much fatigue in this journey." Moses did not get tired till he passed the place about which he was told. There the (servant) boy told Moses, "Do you remember when we betook ourselves to the rock, I indeed forgot the fish." Moses remarked, "That is what we have been seeking. So they went back retracing their footsteps, till they reached the rock. There they saw a man covered with a garment (or covering himself with his own garment). Moses greeted him. Al-Khadir replied saying, "How do people greet each other in your land?" Moses said, "I am Moses." He asked, "The Moses of Bani Israel?" Moses replied in the affirmative and added, "May I follow you so that you teach me of that knowledge which you have been taught." Al-Khadir replied, "Verily! You will not be able to remain patient with me, O Moses! I have some of the knowledge of Allah which He has taught me and which you do not know, while you have some knowledge which Allah has taught you which I do not know." Moses said, "Allah willing, you will find me patient and I will disobey no order of yours. So both of them set out walking along the seashore, as they did not have a boat. In the meantime a boat passed by them and they requested the crew of the boat to take them on board. The crew recognized Al-Khadir and took them on board without fare. Then a sparrow came and stood on the edge of the boat and dipped its beak once or twice in the sea. Al-Khadir said: "O Moses! My knowledge and your knowledge have not decreased Allah's knowledge except as much as this sparrow has decreased the water of the sea with its beak." Al- Khadir went to one of the planks of the boat and plucked it out. Moses said, "These people gave us a free lift but you have broken their boat and scuttled it so as to drown its people." Al-Khadir replied, "Didn't I tell you that you will not be able to remain patient with me." Moses said, "Call me not to account for what I forgot." The first (excuse) of Moses was that he had forgotten. Then they proceeded further and found a boy playing with other boys. Al-Khadir took hold of the boy's head from the top and plucked it out with his hands (i.e. killed him). Moses said, "Have you killed an innocent soul who has killed none." Al-Khadir replied, "Did I not tell you that you cannot remain patient with me?" Then they both proceeded till when they came to the people of a town, they asked them for food, but they refused to entertain them. Then they found there a wall on the point of collapsing. Al-Khadir repaired it with his own hands. Moses said, "If you had wished, surely you could have taken wages for it." Al-Khadir replied, "This is the parting between you and me." The Prophet added, "May Allah be Merciful to Moses! Would that he could have been more patient to learn more about his story with Al-Khadir}}
\hadithdefcmd{bukhari}{123}{حَدَّثَنَا عُثْمَانُ، قَالَ أَخْبَرَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، عَنْ أَبِي مُوسَى، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ، مَا الْقِتَالُ فِي سَبِيلِ اللَّهِ فَإِنَّ أَحَدَنَا يُقَاتِلُ غَضَبًا، وَيُقَاتِلُ حَمِيَّةً‏.‏ فَرَفَعَ إِلَيْهِ رَأْسَهُ ـ قَالَ وَمَا رَفَعَ إِلَيْهِ رَأْسَهُ إِلاَّ أَنَّهُ كَانَ قَائِمًا ـ فَقَالَ ‏ "‏ مَنْ قَاتَلَ لِتَكُونَ كَلِمَةُ اللَّهِ هِيَ الْعُلْيَا فَهُوَ فِي سَبِيلِ اللَّهِ عَزَّ وَجَلَّ ‏"‏‏.‏\hadithno{123}\hadithtrans{Narrated Abu Musa:A man came to the Prophet (ﷺ) and asked, "O Allah's Messenger (ﷺ)! What kind of fighting is in Allah's cause? (I ask this), for some of us fight because of being enraged and angry and some for the sake of his pride and haughtiness." The Prophet (ﷺ) raised his head (as the questioner was standing) and said, "He who fights so that Allah's Word (Islam) should be superior, then he fights in Allah's cause}}
\hadithdefcmd{bukhari}{124}{حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي سَلَمَةَ، عَنِ الزُّهْرِيِّ، عَنْ عِيسَى بْنِ طَلْحَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم عِنْدَ الْجَمْرَةِ وَهُوَ يُسْأَلُ، فَقَالَ رَجُلٌ يَا رَسُولَ اللَّهِ نَحَرْتُ قَبْلَ أَنْ أَرْمِيَ‏.‏ قَالَ ‏"‏ ارْمِ وَلاَ حَرَجَ ‏"‏‏.‏ قَالَ آخَرُ يَا رَسُولَ اللَّهِ حَلَقْتُ قَبْلَ أَنْ أَنْحَرَ‏.‏ قَالَ ‏"‏ انْحَرْ وَلاَ حَرَجَ ‏"‏‏.‏ فَمَا سُئِلَ عَنْ شَىْءٍ قُدِّمَ وَلاَ أُخِّرَ إِلاَّ قَالَ افْعَلْ وَلاَ حَرَجَ‏.‏\hadithno{124}\hadithtrans{Narrated `Abdullah bin `Ammar:I saw the Prophet (ﷺ) near the Jamra and the people were asking him questions (about religious problems). A man asked, "O Allah's Messenger (ﷺ)! I have slaughtered the Hadi (animal) before doing the Rami." The Prophet (ﷺ) replied, "Do the Rami (now) and there is no harm." Another person asked, "O Allah's Messenger (ﷺ)! I got my head shaved before slaughtering the animal." The Prophet (ﷺ) replied, "Do the slaughtering (now) and there is no harm." So on that day, when the Prophet (ﷺ) was asked about anything as regards the ceremonies of Hajj performed before or after its due time his reply was, "Do it (now) and there is no harm}}
\hadithdefcmd{bukhari}{125}{حَدَّثَنَا قَيْسُ بْنُ حَفْصٍ، قَالَ حَدَّثَنَا عَبْدُ الْوَاحِدِ، قَالَ حَدَّثَنَا الأَعْمَشُ، سُلَيْمَانُ عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ بَيْنَا أَنَا أَمْشِي، مَعَ النَّبِيِّ صلى الله عليه وسلم فِي خَرِبِ الْمَدِينَةِ، وَهُوَ يَتَوَكَّأُ عَلَى عَسِيبٍ مَعَهُ، فَمَرَّ بِنَفَرٍ مِنَ الْيَهُودِ، فَقَالَ بَعْضُهُمْ لِبَعْضٍ سَلُوهُ عَنِ الرُّوحِ‏.‏ وَقَالَ بَعْضُهُمْ لاَ تَسْأَلُوهُ لاَ يَجِيءُ فِيهِ بِشَىْءٍ تَكْرَهُونَهُ‏.‏ فَقَالَ بَعْضُهُمْ لَنَسْأَلَنَّهُ‏.‏ فَقَامَ رَجُلٌ مِنْهُمْ فَقَالَ يَا أَبَا الْقَاسِمِ، مَا الرُّوحُ فَسَكَتَ‏.‏ فَقُلْتُ إِنَّهُ يُوحَى إِلَيْهِ‏.‏ فَقُمْتُ، فَلَمَّا انْجَلَى عَنْهُ، قَالَ ‏\{‏وَيَسْأَلُونَكَ عَنِ الرُّوحِ قُلِ الرُّوحُ مِنْ أَمْرِ رَبِّي وَمَا أُوتُيتُمْ مِنَ الْعِلْمِ إِلاَّ قَلِيلاً‏\}‏‏.‏ قَالَ الأَعْمَشُ هَكَذَا فِي قِرَاءَتِنَا‏.‏\hadithno{125}\hadithtrans{Narrated `Abdullah:While I was going with the Prophet (ﷺ) through the ruins of Medina and he was reclining on a date-palm leaf stalk, some Jews passed by. Some of them said to the others: Ask him (the Prophet) about the spirit. Some of them said that they should not ask him that question as he might give a reply which would displease them. But some of them insisted on asking, and so one of them stood up and asked, "O Abul-Qasim ! What is the spirit?" The Prophet (ﷺ) remained quiet. I thought he was being inspired Divinely. So I stayed till that state of the Prophet (while being inspired) was over. The Prophet (ﷺ) then said, "And they ask you (O Muhammad) concerning the spirit --Say: The spirit -- its knowledge is with my Lord. And of knowledge you (mankind) have been given only a little}}
\hadithdefcmd{bukhari}{126}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ إِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَسْوَدِ، قَالَ قَالَ لِي ابْنُ الزُّبَيْرِ كَانَتْ عَائِشَةُ تُسِرُّ إِلَيْكَ كَثِيرًا فَمَا حَدَّثَتْكَ فِي الْكَعْبَةِ قُلْتُ قَالَتْ لِي قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ يَا عَائِشَةُ، لَوْلاَ قَوْمُكِ حَدِيثٌ عَهْدُهُمْ ـ قَالَ ابْنُ الزُّبَيْرِ بِكُفْرٍ ـ لَنَقَضْتُ الْكَعْبَةَ فَجَعَلْتُ لَهَا بَابَيْنِ باب يَدْخُلُ النَّاسُ، وَبَابٌ يَخْرُجُونَ ‏"‏‏.‏ فَفَعَلَهُ ابْنُ الزُّبَيْرِ‏.‏\hadithno{126}\hadithtrans{Narrated Aswad:Ibn Az-Zubair said to me, "Aisha used to tell you secretly a number of things. What did she tell you about the Ka`ba?" I replied, "She told me that once the Prophet (ﷺ) said, 'O `Aisha! Had not your people been still close to the pre-Islamic period of ignorance (infidelity)! I would have dismantled the Ka`ba and would have made two doors in it; one for entrance and the other for exit." Later on Ibn Az-Zubair did the same}}
\hadithdefcmd{bukhari}{127}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى عَنْ مَعْرُوفِ بْنِ خَرَّبُوذٍ عَنْ أَبِي الطُّفَيْلِ عَنْ عَلِيٍّ بِذَلِكَ‏.‏\hadithno{127}\hadithtrans{Narrated Abu at-Tufail:The above mentioned Statement of `Ali}}
\hadithdefcmd{bukhari}{128}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، قَالَ حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم وَمُعَاذٌ رَدِيفُهُ عَلَى الرَّحْلِ قَالَ ‏"‏ يَا مُعَاذُ بْنَ جَبَلٍ ‏"‏‏.‏ قَالَ لَبَّيْكَ يَا رَسُولَ اللَّهِ وَسَعْدَيْكَ‏.‏ قَالَ ‏"‏ يَا مُعَاذُ ‏"‏‏.‏ قَالَ لَبَّيْكَ يَا رَسُولَ اللَّهِ وَسَعْدَيْكَ‏.‏ ثَلاَثًا‏.‏ قَالَ ‏"‏ مَا مِنْ أَحَدٍ يَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنَّ مُحَمَّدًا رَسُولُ اللَّهِ صِدْقًا مِنْ قَلْبِهِ إِلاَّ حَرَّمَهُ اللَّهُ عَلَى النَّارِ ‏"‏‏.‏ قَالَ يَا رَسُولَ اللَّهِ، أَفَلاَ أُخْبِرُ بِهِ النَّاسَ فَيَسْتَبْشِرُوا قَالَ ‏"‏ إِذًا يَتَّكِلُوا ‏"‏‏.‏ وَأَخْبَرَ بِهَا مُعَاذٌ عِنْدَ مَوْتِهِ تَأَثُّمًا ‏.‏\hadithno{128}\hadithtrans{Narrated Anas bin Malik:"Once Mu`adh was along with Allah's Messenger (ﷺ) as a companion rider. Allah's Messenger (ﷺ) said, "O Mu`adh bin Jabal." Mu`adh replied, "Labbaik and Sa`daik. O Allah's Messenger (ﷺ)!" Again the Prophet (ﷺ) said, "O Mu`adh!" Mu`adh said thrice, "Labbaik and Sa`daik, O Allah's Messenger (ﷺ)!" Allah's Messenger (ﷺ) said, "There is none who testifies sincerely that none has the right to be worshipped but Allah and Muhammad is his Apostle, except that Allah, will save him from the Hell-fire." Mu`adh said, "O Allah's Messenger (ﷺ) ! Should I not inform the people about it so that they may have glad tidings?" He replied, "When the people hear about it, they will solely depend on it." Then Mu`adh narrated the above-mentioned Hadith just before his death, being afraid of committing sin (by not telling the knowledge)}}
\hadithdefcmd{bukhari}{129}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا مُعْتَمِرٌ، قَالَ سَمِعْتُ أَبِي قَالَ، سَمِعْتُ أَنَسًا، قَالَ ذُكِرَ لِي أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لِمُعَاذٍ ‏"‏ مَنْ لَقِيَ اللَّهَ لاَ يُشْرِكُ بِهِ شَيْئًا دَخَلَ الْجَنَّةَ ‏"‏‏.‏ قَالَ أَلاَ أُبَشِّرُ النَّاسَ قَالَ ‏"‏ لاَ، إِنِّي أَخَافُ أَنْ يَتَّكِلُوا ‏"‏‏.‏\hadithno{129}\hadithtrans{Narrated Anas:I was informed that the Prophet (ﷺ) had said to Mu`adh, "Whosoever will meet Allah without associating anything in worship with Him will go to Paradise." Mu`adh asked the Prophet, "Should I not inform the people of this good news?" The Prophet (ﷺ) replied, "No, I am afraid, lest they should depend upon it (absolutely)}}
\hadithdefcmd{bukhari}{130}{حَدَّثَنَا مُحَمَّدُ بْنُ سَلاَمٍ، قَالَ أَخْبَرَنَا أَبُو مُعَاوِيَةَ، قَالَ حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ زَيْنَبَ ابْنَةِ أُمِّ سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ جَاءَتْ أُمُّ سُلَيْمٍ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ اللَّهَ لاَ يَسْتَحْيِي مِنَ الْحَقِّ، فَهَلْ عَلَى الْمَرْأَةِ مِنْ غُسْلٍ إِذَا احْتَلَمَتْ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِذَا رَأَتِ الْمَاءَ ‏"‏‏.‏ فَغَطَّتْ أُمُّ سَلَمَةَ ـ تَعْنِي وَجْهَهَا ـ وَقَالَتْ يَا رَسُولَ اللَّهِ وَتَحْتَلِمُ الْمَرْأَةُ قَالَ ‏"‏ نَعَمْ تَرِبَتْ يَمِينُكِ فَبِمَ يُشْبِهُهَا وَلَدُهَا ‏"‏‏.‏\hadithno{130}\hadithtrans{Narrated Um Salama:Um-Sulaim came to Allah's Messenger (ﷺ) and said, "Verily, Allah is not shy of (telling you) the truth. Is it necessary for a woman to take a bath after she has a wet dream (nocturnal sexual discharge?) The Prophet replied, "Yes, if she notices a discharge." Um Salama, then covered her face and asked, "O Allah's Messenger (ﷺ)! Does a woman get a discharge?" He replied, "Yes, let your right hand be in dust (An Arabic expression you say to a person when you contradict his statement meaning "you will not achieve goodness"), and that is why the son resembles his mother}}
\hadithdefcmd{bukhari}{131}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ مِنَ الشَّجَرِ شَجَرَةً لاَ يَسْقُطُ وَرَقُهَا، وَهِيَ مَثَلُ الْمُسْلِمِ، حَدِّثُونِي مَا هِيَ ‏"‏‏.‏ فَوَقَعَ النَّاسُ فِي شَجَرِ الْبَادِيَةِ، وَوَقَعَ فِي نَفْسِي أَنَّهَا النَّخْلَةُ‏.‏ قَالَ عَبْدُ اللَّهِ فَاسْتَحْيَيْتُ‏.‏ فَقَالُوا يَا رَسُولَ اللَّهِ، أَخْبِرْنَا بِهَا‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هِيَ النَّخْلَةُ ‏"‏‏.‏ قَالَ عَبْدُ اللَّهِ فَحَدَّثْتُ أَبِي بِمَا وَقَعَ فِي نَفْسِي فَقَالَ لأَنْ تَكُونَ قُلْتَهَا أَحَبُّ إِلَىَّ مِنْ أَنْ يَكُونَ لِي كَذَا وَكَذَا‏.‏\hadithno{131}\hadithtrans{Narrated `Abdullah bin `Umar:Once Allah's Messenger (ﷺ) said, "Amongst the trees there is a tree, the leaves of which do not fall and is like a Muslim, tell me the name of that tree." Everybody started thinking about the trees of the desert areas and I thought of the date-palm tree but felt shy (to answer). The others asked, "O Allah's Apostle! inform us of it." He replied, "It is the date-palm tree." I told my father what had come to my mind and on that he said, "Had you said it I would have preferred it to such and such a thing that I might possess}}
\hadithdefcmd{bukhari}{132}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دَاوُدَ، عَنِ الأَعْمَشِ، عَنْ مُنْذِرٍ الثَّوْرِيِّ، عَنْ مُحَمَّدٍ ابْنِ الْحَنَفِيَّةِ، عَنْ عَلِيٍّ، قَالَ كُنْتُ رَجُلاً مَذَّاءً فَأَمَرْتُ الْمِقْدَادَ أَنْ يَسْأَلَ النَّبِيَّ صلى الله عليه وسلم فَسَأَلَهُ فَقَالَ ‏ "‏ فِيهِ الْوُضُوءُ ‏"‏‏.‏\hadithno{132}\hadithtrans{Narrated `Ali:I used to get the emotional urethral discharge frequently so I requested Al-Miqdad to ask the Prophet (ﷺ) about it. Al-Miqdad asked him and he replied, "One has to perform ablution (after it)." (See Hadith No)}}
\hadithdefcmd{bukhari}{133}{حَدَّثَنِي قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، قَالَ حَدَّثَنَا نَافِعٌ، مَوْلَى عَبْدِ اللَّهِ بْنِ عُمَرَ بْنِ الْخَطَّابِ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ،‏.‏ أَنَّ رَجُلاً، قَامَ فِي الْمَسْجِدِ فَقَالَ يَا رَسُولَ اللَّهِ، مِنْ أَيْنَ تَأْمُرُنَا أَنْ نُهِلَّ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يُهِلُّ أَهْلُ الْمَدِينَةِ مِنْ ذِي الْحُلَيْفَةِ، وَيُهِلُّ أَهْلُ الشَّأْمِ مِنَ الْجُحْفَةِ، وَيُهِلُّ أَهْلُ نَجْدٍ مِنْ قَرْنٍ ‏"‏‏.‏ وَقَالَ ابْنُ عُمَرَ وَيَزْعُمُونَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ وَيُهِلُّ أَهْلُ الْيَمَنِ مِنْ يَلَمْلَمَ ‏"‏‏.‏ وَكَانَ ابْنُ عُمَرَ يَقُولُ لَمْ أَفْقَهْ هَذِهِ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{133}\hadithtrans{Narrated Nafi`:`Abdullah bin `Umar said: "A man got up in the mosque and said: 'O Allah's Messenger (ﷺ) At which place you order us that we should assume the Ihram?' Allah's Messenger (ﷺ) replied, 'The residents of Medina should assure the Ihram from Dhil-Hulaifa, the people of Syria from Al-Juhfa and the people of Najd from Qarn." Ibn `Umar further said, "The people consider that Allah's Messenger (ﷺ) had also said, 'The residents of Yemen should assume Ihram from Yalamlam.' " Ibn `Umar used to say, "I do not remember whether Allah's Messenger (ﷺ) had said the last statement or not}}
\hadithdefcmd{bukhari}{134}{حَدَّثَنَا آدَمُ، قَالَ حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ وَعَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّ رَجُلاً سَأَلَهُ مَا يَلْبَسُ الْمُحْرِمُ فَقَالَ ‏ "‏ لاَ يَلْبَسِ الْقَمِيصَ وَلاَ الْعِمَامَةَ وَلاَ السَّرَاوِيلَ وَلاَ الْبُرْنُسَ وَلاَ ثَوْبًا مَسَّهُ الْوَرْسُ أَوِ الزَّعْفَرَانُ، فَإِنْ لَمْ يَجِدِ النَّعْلَيْنِ فَلْيَلْبَسِ الْخُفَّيْنِ وَلْيَقْطَعْهُمَا حَتَّى يَكُونَا تَحْتَ الْكَعْبَيْنِ ‏"‏‏.‏\hadithno{134}\hadithtrans{Narrated Ibn `Umar:A man asked the Prophet (ﷺ) : "What (kinds of clothes) should a Muhrim (a Muslim intending to perform `Umra or Hajj) wear? He replied, "He should not wear a shirt, a turban, trousers, a head cloak or garment scented with saffron or Wars (kinds of perfumes). And if he has no slippers, then he can use Khuffs (socks made from thick fabric or leather) but the socks should be cut short so as to make the ankles bare." (See Hadith No. 615, Vol)}}
